@@ -24,6 +24,7 @@
 #include "GraphicContext.h"
 #include <vector>
 #include <set>
+#include <cassert>
 
 namespace GAGCore
 {
@@ -93,31 +94,111 @@ namespace GAGGUI
 	//! A widget is a GUI block element
 	class Widget
 	{
+	private:
+		//! Tooltip text, empty if no tooltip
+		std::string tooltip;
+		//! Tick id from last mouse move
+		Uint32 lastIdleTick;
+		//! Current tick id
+		Uint32 currentTick;
+		//! Mouse position
+		int mx, my;
+		//! Tooltip font name
+		std::string tooltipFont;
+		//! We need a font to draw the tooltip
+		GAGCore::Font *tooltipFontPtr;
 	public:
-			//! if the widget is visible it receive paint event, timer event and SDL event. Otherwise it receive no events.
+		//! if the widget is visible it receive paint event, timer event and SDL event. Otherwise it receive no events.
 		bool visible;
 	
 	public:
-		//! Widget constructor
+		//! Construct a Widget without tooltip
 		Widget();
+		/*! Widget constructor, with a tooltip.
+		 * \param tooltip Text displayed in tooltip.
+		 * \param tooltipFont Name of the font used to draw the tooltip.
+		 */
+		Widget(const std::string& tooltip, const std::string &tooltipFont);
 		//! Widget destructor
 		virtual ~Widget();
 	
-		//! Method called for each timer's tick
+		/*! Set the widget's tooltip.
+		 * \param tt Text displayed in tooltip
+		 * \param tooltipFont Name of the font used to draw the tooltip.
+		 */
+		void setTooltip(const std::string &tt, const std::string &tooltipFont);
+		/*! Called by Screen when a timer tick occurs.
+		 * This is a template method (a kind of skeletton), you
+		 * can't override it. It call onTimer wich should contain
+		 * Widget's specific timer handling stuff */
+		void timerTick(Uint32 tick);
+		/*! Specific method called for each timer's tick.
+		 * \param tick ID of the SDL timer tick
+		 */
 		virtual void onTimer(Uint32 tick) { }
-		//! Method called for each SDL_Event
-		virtual void onSDLEvent(SDL_Event *event) { }
+		/*! Method called for events not handled by onSDLxxx
+		 * shouldn't be useful (since such events are joystick stuff).
+		 * If you find an event wich is not handled by onSDLxxx
+		 * it's probably better to add an onSDLxxx method and modify
+		 * Screen::dispatchEvents.
+		 * \param event Event generated by SDL.
+		 */
+		virtual void onSDLOtherEvent(SDL_Event *event) { }
 		//! Drawing methode of the widget
 		virtual void paint(void) = 0;
-		//! Init the widget, called before the first paint
-		virtual void init(void) { }
-	
+		//! Draw the tooltip
+		void displayTooltip(void);
+		/*! Initialize internal Widget's data. Subclasses
+		 * can perform additional initialization by overriding
+		 * internalInit */
+		void init(void);
+		//! Specific initialization of the widget. Called before the first paint
+		virtual void internalInit(void) { };
+		/*! Indicate if a point is over the Widget.
+		 * \param x point's x-coordinate
+		 * \param y point's y-coordinate
+		 * \return true if the point is over the widget, false otherwise.
+		 */
+		virtual bool isOnWidget(int x, int y) = 0;
 	protected:
 		friend class Screen;
-		//! Return true if (px,py) is in the rect (x,y)-(x+w,y+h)
-		bool isPtInRect(int px, int py, int x, int y, int w, int h) { if ((px>x) && (py>y) && (px<x+w) && (py<y+h)) return true; else return false; }
-		//! Screen that contains the widget
 		Screen *parent;
+		/*! Called when an SDL_MOUSEMOTION event occurs.
+		 * As timertick, this is a template method,
+		 * subclasses who want to perform specific actions
+		 * when a mouse motion event occurs should override
+		 * onSDLMouseMotion.
+		 * \param event Catched SDL event.
+		 */
+		void SDLMouseMotion(SDL_Event *event);
+		/*! Called when an SDL_ACTIVEEVENT event occurs.
+		 * \param event Catched SDL event
+		 */
+		virtual void onSDLActive(SDL_Event *event) { assert(event->type == SDL_ACTIVEEVENT); }
+		/*! Called when an SDL_KEYDOWN event occurs.
+		 * \param event Catched SDL event
+		 */
+		virtual void onSDLKeyDown(SDL_Event *event) { assert(event->type == SDL_KEYDOWN); }
+		/*! Called when an SDL_KEYUP event occurs.
+		 * \param event Catched SDL event
+		 */
+		virtual void onSDLKeyUp(SDL_Event *event) { assert(event->type == SDL_KEYUP); }
+		/*! Called when an SDL_MOUSEMOTION event occurs.
+		 * \param event Catched SDL event
+		 */
+		virtual void onSDLMouseMotion(SDL_Event *event) { assert(event->type == SDL_MOUSEMOTION); }
+		/*! Called when an SDL_MOUSEBUTTONUP event occurs.
+		 * \param event Catched SDL event
+		 */
+		virtual void onSDLMouseButtonUp(SDL_Event *event) { assert(event->type == SDL_MOUSEBUTTONUP); }
+		/*! Called when an SDL_MOUSEBUTTONDOWN event occurs.
+		 * \param event Catched SDL event
+		 */
+		virtual void onSDLMouseButtonDown(SDL_Event *event) { assert(event->type == SDL_MOUSEBUTTONDOWN); }
+		/*! Called when an SDL_VIDEOEXPOSE event occurs.
+		 * \param event Catched SDL event
+		 */
+		virtual void onSDLVideoExpose(SDL_Event *event) { assert(event->type == SDL_VIDEOEXPOSE); }
 	};
 	
 	#define ALIGN_LEFT 0
@@ -138,25 +219,31 @@ namespace GAGGUI
 		Sint32 h;
 		Uint32 hAlignFlag;
 		Uint32 vAlignFlag;
-	
 	public:
 		//! RectangularWidget constructor, set all values to 0
 		RectangularWidget();
+		//! Constructs a Widget with a tooltip
+		RectangularWidget(const std::string& tooltip, const std::string &tooltipFont);
 		//! RectangularWidget destructor
 		virtual ~RectangularWidget() { }
-	
+
 		//! Show the widget, put in queue for end of step
 		virtual void show(void);
 	
 		//! Hide the widget, put in queue for end of step
 		virtual void hide(void);
-	
+
 		//! Show or hide the widget, call show or hide depending on visibe
 		virtual void setVisible(bool visible);
+
+		//! \copydoc Widget::isOnWidget
+		virtual bool isOnWidget(int x, int y);
 	
 	protected:
 		//! Compute the actual position from the layout informations
 		virtual void getScreenPos(int *sx, int *sy, int *sw, int *sh);
+		bool isPtInRect(int px, int py, int x, int y, int w, int h) { if ((px>x) && (py>y) && (px<x+w) && (py<y+h)) return true; else return false; }
+		//! Screen that contains the widget
 	};
 	
 	//! This class provides highlight support through mouse motion detection
@@ -172,15 +259,17 @@ namespace GAGGUI
 	
 	public:
 		HighlightableWidget();
+		HighlightableWidget(const std::string& tooltip, const std::string &tooltipFont);
 		HighlightableWidget(Sint32 returnCode);
+		HighlightableWidget(const std::string& tooltip, const std::string &tooltipFont, Sint32 returnCode);
 	
 		virtual ~HighlightableWidget() {}
 	
 		virtual void paint(void);
-		virtual void onSDLEvent(SDL_Event *event);
 		
 	protected:
 		unsigned getNextHighlightValue(void);
+		virtual void onSDLMouseMotion(SDL_Event *event);
 	};
 	
 	//! The screen is the widget container and has a background
