@@ -39,9 +39,14 @@ namespace GAGGUI
 	public:
 		Button() {  }
 		Button(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *sprite, int standardId, int highlightID, int returnCode, Uint16 unicodeShortcut=0);
+		Button(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *sprite, int standardId, int highlightID, int returnCode,
+			const std::string& tooltip, const std::string &font, Uint16 unicodeShortcut=0);
 		virtual ~Button() { }
 	
-		virtual void onSDLEvent(SDL_Event *event);
+	protected:
+		virtual void onSDLKeyDown(SDL_Event *event);
+		virtual void onSDLMouseButtonDown(SDL_Event *event);
+		virtual void onSDLMouseButtonUp(SDL_Event *event);
 	};
 	
 	class TextButton:public Button
@@ -55,12 +60,15 @@ namespace GAGGUI
 	
 	public:
 		TextButton() { fontPtr=NULL; }
-		TextButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *sprite, int standardId, int highlightID, const char *font, const char *text, int retuxrnCode, Uint16 unicodeShortcut=0);
+		TextButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *sprite, int standardId, int highlightID, const char *font, const char *text, int returnCode,
+		const std::string& tooltip, const std::string &tooltipFont, Uint16 unicode=0);
+		TextButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *sprite, int standardId, int highlightID, const char *font, const char *text, int returxnCode, Uint16 unicodeShortcut=0);
 		virtual ~TextButton() { }
-		virtual void init(void);
+		virtual void internalInit(void);
 		virtual void paint(void);
 	
 		void setText(const char *text);
+		void setText(const std::string &text) { setText(text.c_str()); }
 	};
 	
 	class OnOffButton:public HighlightableWidget
@@ -70,13 +78,17 @@ namespace GAGGUI
 	
 	public:
 		OnOffButton() { state=false; returnCode=0; }
+		OnOffButton(const std::string &tooltip, const std::string &tooltipFont) :HighlightableWidget(tooltip, tooltipFont) { state=false; returnCode=0; }
 		OnOffButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, bool startState, int returnCode);
+		OnOffButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, bool startState, int returnCode, const std::string &tooltip, const std::string &tooltipFont);
 		virtual ~OnOffButton() { }
 	
-		virtual void onSDLEvent(SDL_Event *event);
 		virtual void paint(void);
 		virtual bool getState(void) { return state; }
 		virtual void setState(bool newState);
+	protected:
+		virtual void onSDLMouseButtonDown(SDL_Event *event);
+		virtual void onSDLMouseButtonUp(SDL_Event *event);
 	};
 	
 	//! A button that can have multiple color
@@ -101,11 +113,11 @@ namespace GAGGUI
 		ColorButton() { selColor=returnCode=0; }
 		//! ColorButton constructor
 		ColorButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, int returnCode);
+		//! With a tooltip
+		ColorButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const std::string& tooltip, const std::string &tooltipFont, int returnCode);
 		//! ColorButton destructor
 		virtual ~ColorButton() { }
 	
-		//! Process SDL event
-		virtual void onSDLEvent(SDL_Event *event);
 		virtual void paint(void);
 		//! Add a color to the color list
 		virtual void addColor(int r, int g, int b) { v.push_back(Color(r, g, b)); }
@@ -117,28 +129,36 @@ namespace GAGGUI
 		virtual int getSelectedColor(void) { return selColor; }
 		//! Return the number of possible colors
 		virtual size_t getNumberOfColors(void) { return v.size(); }
+	protected:
+		virtual void onSDLMouseButtonUp(SDL_Event *event);
+		virtual void onSDLMouseButtonDown(SDL_Event *event);
 	};
 	
 	//! A button that can have multiple texts
 	class MultiTextButton:public TextButton
 	{
 	protected:
-		std::vector<const char *> texts;
+		std::vector<std::string> texts;
 		unsigned textIndex;
 	
 	public:
 		MultiTextButton() { textIndex=0; returnCode=0; }
 		MultiTextButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *sprite, int standardId, int highlightID, const char *font, const char *text, int retuxrnCode, Uint16 unicodeShortcut=0);
+		MultiTextButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *sprite, int standardId, int highlightID, const char *font, const char *text, int retuxrnCode, const std::string& tooltip, const std::string &tooltipFont, Uint16 unicodeShortcut=0);
 		virtual ~MultiTextButton() { }
 	
-		virtual void onSDLEvent(SDL_Event *event);
 		
-		virtual void addText(const char *s);
-		virtual void clearTexts(void);
-		virtual void setTextIndex(int i);
-		virtual void setFirstTextIndex(int i);
-		virtual int getTextIndex(void) { return textIndex; }
-		virtual size_t getTextsSize(void) { return texts.size(); }
+		void addText(const char *s);
+		void addText(const std::string &s) { addText(s.c_str()); }
+		const std::string &getText(void) const { return texts.at(textIndex); }
+		void clearTexts(void);
+		void setIndex(int i);
+		void setIndexFromText(const std::string &s);
+		int getIndex(void) const { return textIndex; }
+		size_t getCount(void) const { return texts.size(); }
+	protected:
+		virtual void onSDLMouseButtonDown(SDL_Event *event);
+		virtual void onSDLMouseButtonUp(SDL_Event *event);
 	};
 }
 
