@@ -45,11 +45,12 @@ namespace GAGGUI
 	
 	public:
 		Number();
+		Number(const std::string& tooltip, const std::string &tooltipFont);
 		Number(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, int m, const char *font);
+		Number(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, int m, const char *font, const std::string& tooltip, const std::string &tooltipFont);
 		virtual ~Number();
 	
-		virtual void onSDLEvent(SDL_Event *event);
-		virtual void init(void);
+		virtual void internalInit(void);
 		virtual void paint(void);
 	
 		void add(int number);
@@ -58,6 +59,8 @@ namespace GAGGUI
 		void set(int number);
 		int getNth(void);
 		int get(void);
+	protected:
+		virtual void onSDLMouseButtonDown(SDL_Event *event);
 	};
 }
 
