@@ -39,33 +39,45 @@ namespace GAGGUI
 	
 		this->unicodeShortcut=unicodeShortcut;
 	}
-	
-	
-	void Button::onSDLEvent(SDL_Event *event)
+
+	Button::Button(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *sprite, int standardId, int highlightID, int returnCode,
+		const std::string& tooltip, const std::string &tooltipFont, Uint16 unicodeShortcut)
+	:HighlightableWidget(tooltip, tooltipFont, returnCode)
 	{
+		this->x=x;
+		this->y=y;
+		this->w=w;
+		this->h=h;
+		this->hAlignFlag=hAlign;
+		this->vAlignFlag=vAlign;
+	
+		this->unicodeShortcut=unicodeShortcut;
+	}
+	
+	void Button::onSDLKeyDown(SDL_Event *event)
+	{
+		assert(event->type == SDL_KEYDOWN);
 		int x, y, w, h;
 		getScreenPos(&x, &y, &w, &h);
+		Uint16 typedUnicode=event->key.keysym.unicode;
+		if ((unicodeShortcut)&&(typedUnicode==unicodeShortcut))
+			parent->onAction(this, BUTTON_SHORTCUT, returnCode, unicodeShortcut);
+	}
+
+	void Button::onSDLMouseButtonDown(SDL_Event *event)
+	{
+		assert(event->type == SDL_MOUSEBUTTONDOWN);
+		if (isOnWidget(event->button.x, event->button.y) &&
+				  (event->button.button == SDL_BUTTON_LEFT))
+		parent->onAction(this, BUTTON_PRESSED, returnCode, 0);
+	}
 	
-		HighlightableWidget::onSDLEvent(event);
-	
-		if (event->type==SDL_KEYDOWN)
-		{
-			Uint16 typedUnicode=event->key.keysym.unicode;
-			if ((unicodeShortcut)&&(typedUnicode==unicodeShortcut))
-				parent->onAction(this, BUTTON_SHORTCUT, returnCode, unicodeShortcut);
-		}
-		else if (event->type==SDL_MOUSEBUTTONDOWN)
-		{
-			if (isPtInRect(event->button.x, event->button.y, x, y, w, h) &&
+	void Button::onSDLMouseButtonUp(SDL_Event *event)
+	{
+		assert(event->type == SDL_MOUSEBUTTONUP);
+		if (isOnWidget(event->button.x, event->button.y) &&
 				(event->button.button == SDL_BUTTON_LEFT))
-				parent->onAction(this, BUTTON_PRESSED, returnCode, 0);
-		}
-		else if (event->type==SDL_MOUSEBUTTONUP)
-		{
-			if (isPtInRect(event->button.x, event->button.y, x, y, w, h) &&
-				(event->button.button == SDL_BUTTON_LEFT))
-				parent->onAction(this, BUTTON_RELEASED, returnCode, 0);
-		}
+			parent->onAction(this, BUTTON_RELEASED, returnCode, 0);
 	}
 	
 	
@@ -78,10 +90,22 @@ namespace GAGGUI
 		this->text=text;
 		fontPtr=NULL;
 	}
-	
-	void TextButton::init(void)
+
+	TextButton::TextButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *sprite, int standardId, int highlightID, const char *font, const char *text, int returnCode,
+		const std::string& tooltip, const std::string &tooltipFont, Uint16 unicode)
+		:Button(x, y, w, h, hAlign, vAlign, sprite, standardId, highlightID, returnCode, tooltip, tooltipFont, unicode)
 	{
-		Button::init();
+		assert(font);
+		assert(text);
+		this->font=font;
+		this->text=text;
+		fontPtr=NULL;
+	}
+
+
+	void TextButton::internalInit(void)
+	{
+		Button::internalInit();
 		fontPtr = Toolkit::getFont(font.c_str());
 		assert(fontPtr);
 	}
@@ -122,28 +146,36 @@ namespace GAGGUI
 		this->state=startState;
 	}
 	
-	void OnOffButton::onSDLEvent(SDL_Event *event)
+	OnOffButton::OnOffButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, bool startState, int returnCode, const std::string &tooltip, const std::string &tooltipFont)
+	:HighlightableWidget(tooltip, tooltipFont, returnCode)
 	{
-		int x, y, w, h;
-		getScreenPos(&x, &y, &w, &h);
+		this->x=x;
+		this->y=y;
+		this->w=w;
+		this->h=h;
+		this->hAlignFlag=hAlign;
+		this->vAlignFlag=vAlign;
 	
-		HighlightableWidget::onSDLEvent(event);
+		this->state=startState;
+	}
 	
-		if (event->type==SDL_MOUSEBUTTONDOWN)
+	void OnOffButton::onSDLMouseButtonDown(SDL_Event *event)
+	{
+		assert(event->type == SDL_MOUSEBUTTONDOWN);
+		if (isOnWidget(event->button.x, event->button.y) &&
+			(event->button.button == SDL_BUTTON_LEFT))
 		{
-			if (isPtInRect(event->button.x, event->button.y, x, y, w, h) &&
-				(event->button.button == SDL_BUTTON_LEFT))
-			{
-				state=!state;
-				parent->onAction(this, BUTTON_PRESSED, returnCode, 0);
-				parent->onAction(this, BUTTON_STATE_CHANGED, returnCode, state == true ? 1 : 0);
-			}
+			state=!state;
+			parent->onAction(this, BUTTON_PRESSED, returnCode, 0);
+			parent->onAction(this, BUTTON_STATE_CHANGED, returnCode, state == true ? 1 : 0);
 		}
-		else if (event->type==SDL_MOUSEBUTTONUP)
-		{
-			if (isPtInRect(event->button.x, event->button.y, x, y, w, h))
+	}
+	
+	void OnOffButton::onSDLMouseButtonUp(SDL_Event *event)
+	{
+		assert(event->type == SDL_MOUSEBUTTONUP);
+		if (isOnWidget(event->button.x, event->button.y))
 				parent->onAction(this, BUTTON_RELEASED, returnCode, 0);
-		}
 	}
 	
 	void OnOffButton::paint()
@@ -177,45 +209,51 @@ namespace GAGGUI
 	
 		selColor=0;
 	}
-	
-	void ColorButton::onSDLEvent(SDL_Event *event)
+
+	ColorButton::ColorButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const std::string& tooltip, const std::string &tooltipFont, int returnCode)
+	:HighlightableWidget(tooltip, tooltipFont, returnCode)
 	{
-		int x, y, w, h;
-		getScreenPos(&x, &y, &w, &h);
+		this->x=x;
+		this->y=y;
+		this->w=w;
+		this->h=h;
+		this->hAlignFlag=hAlign;
+		this->vAlignFlag=vAlign;
 	
-		HighlightableWidget::onSDLEvent(event);
+		selColor=0;
+	}
 	
-		if (event->type==SDL_MOUSEBUTTONDOWN)
+	void ColorButton::onSDLMouseButtonDown(SDL_Event *event)
+	{
+		if (isOnWidget(event->button.x, event->button.y) && v.size())
 		{
-			if (isPtInRect(event->button.x, event->button.y, x, y, w, h) && v.size())
+			if (event->button.button == SDL_BUTTON_LEFT)
 			{
-				if (event->button.button == SDL_BUTTON_LEFT)
-				{
-					selColor++;
-					if (selColor>=(signed)v.size())
-						selColor=0;
-	
-					parent->onAction(this, BUTTON_STATE_CHANGED, returnCode, selColor);
-					parent->onAction(this, BUTTON_PRESSED, returnCode, 0);
-				}
-				else if (event->button.button == SDL_BUTTON_RIGHT)
-				{
-					selColor--;
-					if (selColor<0)
-						selColor=(signed)v.size()-1;
-					
-					parent->onAction(this, BUTTON_STATE_CHANGED, returnCode, selColor);
-					parent->onAction(this, BUTTON_PRESSED, returnCode, 0);
-				}
+				selColor++;
+				if (selColor>=(signed)v.size())
+					selColor=0;
+		
+				parent->onAction(this, BUTTON_STATE_CHANGED, returnCode, selColor);
+				parent->onAction(this, BUTTON_PRESSED, returnCode, 0);
+			}
+			else if (event->button.button == SDL_BUTTON_RIGHT)
+			{
+				selColor--;
+				if (selColor<0)
+					selColor=(signed)v.size()-1;
+				
+				parent->onAction(this, BUTTON_STATE_CHANGED, returnCode, selColor);
+				parent->onAction(this, BUTTON_PRESSED, returnCode, 0);
 			}
 		}
-		else if (event->type==SDL_MOUSEBUTTONUP)
-		{
-			if (isPtInRect(event->button.x, event->button.y, x, y, w, h) &&
+	}
+	
+	void ColorButton::onSDLMouseButtonUp(SDL_Event *event)
+	{
+		if (isOnWidget(event->button.x, event->button.y) &&
 				(event->button.button == SDL_BUTTON_LEFT))
-			{
-				parent->onAction(this, BUTTON_RELEASED, returnCode, 0);
-			}
+		{
+			parent->onAction(this, BUTTON_RELEASED, returnCode, 0);
 		}
 	}
 	
@@ -235,50 +273,50 @@ namespace GAGGUI
 	MultiTextButton::MultiTextButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *sprite, int standardId, int highlightID, const char *font, const char *text, int returnCode, Uint16 unicode)
 	:TextButton(x, y, w, h, hAlign, vAlign, sprite, standardId, highlightID, font, text, returnCode, unicode)
 	{
-		textIndex=0;
+		textIndex = 0;
+	}
+	MultiTextButton::MultiTextButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *sprite, int standardId, int highlightID, const char *font, const char *text, int returnCode, const std::string& tooltip, const std::string &tooltipFont, Uint16 unicode)
+	:TextButton(x, y, w, h, hAlign, vAlign, sprite, standardId, highlightID, font, text, returnCode, tooltip, tooltipFont, unicode)
+	{
+		textIndex = 0;
 	}
 	
-	void MultiTextButton::onSDLEvent(SDL_Event *event)
+	void MultiTextButton::onSDLMouseButtonDown(SDL_Event *event)
 	{
-		int x, y, w, h;
-		getScreenPos(&x, &y, &w, &h);
-	
-		HighlightableWidget::onSDLEvent(event);
-	
-		if (event->type==SDL_MOUSEBUTTONDOWN)
+		assert(event->type == SDL_MOUSEBUTTONDOWN);
+		if (isOnWidget(event->button.x, event->button.y) && texts.size())
 		{
-			if (isPtInRect(event->button.x, event->button.y, x, y, w, h) && texts.size())
+			if (event->button.button == SDL_BUTTON_LEFT)
 			{
-				if (event->button.button == SDL_BUTTON_LEFT)
-				{
-					textIndex++;
-					if (textIndex >= texts.size())
-						textIndex = 0;
-					setText(texts.at(textIndex));
+				textIndex++;
+				if (textIndex >= texts.size())
+					textIndex = 0;
+				setText(texts.at(textIndex));
 	
-					parent->onAction(this, BUTTON_STATE_CHANGED, returnCode, textIndex);
-					parent->onAction(this, BUTTON_PRESSED, returnCode, 0);
-				}
-				else if (event->button.button == SDL_BUTTON_RIGHT)
-				{
-					if (textIndex > 0)
-						textIndex--;
-					else
-						textIndex = texts.size()-1;
-					setText(texts.at(textIndex));
-					
-					parent->onAction(this, BUTTON_STATE_CHANGED, returnCode, textIndex);
-					parent->onAction(this, BUTTON_PRESSED, returnCode, 0);
-				}
+				parent->onAction(this, BUTTON_STATE_CHANGED, returnCode, textIndex);
+				parent->onAction(this, BUTTON_PRESSED, returnCode, 0);
+			}
+			else if (event->button.button == SDL_BUTTON_RIGHT)
+			{
+				if (textIndex > 0)
+					textIndex--;
+				else
+					textIndex = texts.size()-1;
+				setText(texts.at(textIndex));
+				
+				parent->onAction(this, BUTTON_STATE_CHANGED, returnCode, textIndex);
+				parent->onAction(this, BUTTON_PRESSED, returnCode, 0);
 			}
 		}
-		else if (event->type==SDL_MOUSEBUTTONUP)
+	}
+	
+	void MultiTextButton::onSDLMouseButtonUp(SDL_Event *event)
+	{
+		assert(event->type == SDL_MOUSEBUTTONUP);
+		if (isOnWidget(event->button.x, event->button.y) &&
+			(event->button.button == SDL_BUTTON_LEFT))
 		{
-			if (isPtInRect(event->button.x, event->button.y, x, y, w, h) &&
-				(event->button.button == SDL_BUTTON_LEFT))
-			{
-				parent->onAction(this, BUTTON_RELEASED, returnCode, 0);
-			}
+			parent->onAction(this, BUTTON_RELEASED, returnCode, 0);
 		}
 	}
 	
@@ -292,15 +330,18 @@ namespace GAGGUI
 		texts.clear();
 	}
 	
-	void MultiTextButton::setTextIndex(int i)
+	void MultiTextButton::setIndex(int i)
 	{
-		textIndex=i;
+		textIndex = i;
 		setText(texts.at(textIndex));
 	}
 	
-	void MultiTextButton::setFirstTextIndex(int i)
+	void MultiTextButton::setIndexFromText(const std::string &s)
 	{
-		textIndex=i;
-		text=texts.at(textIndex);
+		for (size_t i = 0; i < texts.size(); i++)
+		{
+			if (texts[i] == s)
+				setIndex(i);
+		}
 	}
 }
