@@ -32,6 +32,12 @@ namespace GAGGUI
 		x = y = w = h = m = nth = 0;
 	}
 	
+	Number::Number(const std::string &tooltip, const std::string &tooltipFont)
+		:HighlightableWidget(tooltip, tooltipFont)
+	{
+		x = y = w = h = m = nth = 0;
+	}
+	
 	Number::Number(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, int m, const char *font)
 	{
 		assert(font);
@@ -49,48 +55,63 @@ namespace GAGGUI
 		nth=0;
 	}
 	
+	Number::Number(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, int m, const char *font, const std::string &tooltip, const std::string &tooltipFont)
+		: HighlightableWidget(tooltip, tooltipFont)
+	{
+		assert(font);
+		this->font = font;
+		this->x=x;
+		this->y=y;
+		this->w=w;
+		this->h=h;
+		this->hAlignFlag=hAlign;
+		this->vAlignFlag=vAlign;
+	
+		if (m<1)
+			m=h;
+		this->m=m;
+		nth=0;
+	}
+	
 	Number::~Number()
 	{
 		// Let's sing.
 	}
 	
-	void Number::onSDLEvent(SDL_Event *event)
+	void Number::onSDLMouseButtonDown(SDL_Event *event)
 	{
+		assert(event->type == SDL_MOUSEBUTTONDOWN);
 		int x, y, w, h;
 		getScreenPos(&x, &y, &w, &h);
-		
-		HighlightableWidget::onSDLEvent(event);
-		
-		if (event->type==SDL_MOUSEBUTTONDOWN)
+		// We can't use isOnWidget since x, y, w, h are needed
+		// out of the test
+		if (isPtInRect(event->button.x, event->button.y, x, y, w, h))
 		{
-			if (isPtInRect(event->button.x, event->button.y, x, y, w, h))
+			if (event->button.x-x<m)
 			{
-				if (event->button.x-x<m)
+				// a "Less" click
+				if (nth>0)
 				{
-					// a "Less" click
-					if (nth>0)
+					nth--;
+					if (numbers.size()>0)
 					{
-						nth--;
-						if (numbers.size()>0)
-						{
-							parent->onAction(this, NUMBER_ELEMENT_SELECTED, nth, 0);
-						}
-					}
-				}
-				else if (x+w-event->button.x<m)
-				{
-					// a "More" click
-					if (nth<((int)numbers.size()-1))
-					{
-						nth++;
 						parent->onAction(this, NUMBER_ELEMENT_SELECTED, nth, 0);
 					}
 				}
 			}
+			else if (x+w-event->button.x<m)
+			{
+				// a "More" click
+				if (nth<((int)numbers.size()-1))
+				{
+					nth++;
+					parent->onAction(this, NUMBER_ELEMENT_SELECTED, nth, 0);
+				}
+			}
 		}
 	}
 	
-	void Number::init(void)
+	void Number::internalInit(void)
 	{
 		this->fontPtr=Toolkit::getFont(font.c_str());
 		assert(fontPtr);
