@@ -44,11 +44,12 @@ public:
 		NUMBI=1,
 		CASTOR=2,
 		NICOWAR=3,
+		WARRUSH=4,
+		REACHTOINFINITY=5,
 		
 		SIZE,
 		
 		TOUBIB,
-		WARRUSH,
 		
 		EXPERIMENTAL_SIZE
 	};
