@@ -1,6 +1,5 @@
 /*
- Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
- for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+ Copyright 2005-2006 Bradley Arsenault
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -47,7 +46,7 @@ namespace Nicowar
 	///This constant turns on status output. status is output to the file "NicowarStatus.txt" in the current
 	///working directory. It has plenty of information that explains nicowars choices, which is good for
 	///fine tuning Nicowar as well as debugging it.
-	const bool NicowarStatusUpdate = true;
+	const bool NicowarStatusUpdate = false;
 
 	class AINicowar;
 	class Module;
@@ -747,12 +746,12 @@ namespace Nicowar
 			struct GradientPoll
 			{
 				GradientPoll() : is_null(true) {}
-				GradientPoll(Gradient::Sources source, Gradient::Obstacles obstacle, float weight) : is_null(false), source(source), obstacle(obstacle), weight(weight), min_dist(-1), max_dist(-1) {}
+				GradientPoll(Gradient::Sources source, Gradient::Obstacles obstacle, int weight) : is_null(false), source(source), obstacle(obstacle), weight(weight), min_dist(-1), max_dist(-1) {}
 				GradientPoll(Gradient::Sources source, Gradient::Obstacles obstacle, int minimum_distance, int maximum_distance) : is_null(false), source(source), obstacle(obstacle), weight(1), min_dist(minimum_distance), max_dist(maximum_distance) {}
  				bool is_null;
 				Gradient::Sources source;
 				Gradient::Obstacles obstacle;
-				float weight;
+				int weight;
 				int min_dist;
 				int max_dist;
 			};
@@ -1343,17 +1342,17 @@ namespace Nicowar
 	const unsigned MAXIMUM_DISTANCE_TO_BUILDING=8;
 	typedef DistributedNewConstructionManager::GradientPoll GradientPoll;
 	const GradientPoll CONSTRUCTION_FACTORS[IntBuildingType::NB_BUILDING][CONSTRUCTOR_FACTORS_COUNT] = 
-		{{	GradientPoll(Gradient::Wheat, Gradient::None, 2),
-			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 1), 
-			GradientPoll(Gradient::VillageCenter, Gradient::Resource, 0.5)}, //swarm
+		{{	GradientPoll(Gradient::Wheat, Gradient::None, 4),
+			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 2), 
+			GradientPoll(Gradient::VillageCenter, Gradient::Resource, 1)}, //swarm
 
-		 {	GradientPoll(Gradient::Wheat, Gradient::None, 2), 
-			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 1), 
-			GradientPoll(Gradient::VillageCenter, Gradient::Resource, 0.5)}, //inn
+		 {	GradientPoll(Gradient::Wheat, Gradient::None, 4), 
+			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 2), 
+			GradientPoll(Gradient::VillageCenter, Gradient::Resource, 1)}, //inn
 
-		 {	GradientPoll(Gradient::Wood, Gradient::None, 1), 
-			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 1), 
-			GradientPoll(Gradient::VillageCenter, Gradient::Resource, 0.5)}, //hospital
+		 {	GradientPoll(Gradient::Wood, Gradient::None, 2), 
+			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 2), 
+			GradientPoll(Gradient::VillageCenter, Gradient::Resource, 1)}, //hospital
 
 		 {	GradientPoll(Gradient::VillageCenter, Gradient::Resource, 1), 
 			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 2), 
@@ -1363,16 +1362,16 @@ namespace Nicowar
 			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 2), 
 			GradientPoll()}, //swimming pool
 
-		 {	GradientPoll(Gradient::Stone, Gradient::None, 2), 
-			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 1), 
-			GradientPoll(Gradient::VillageCenter, Gradient::Resource, 0.5)}, //barracks
+		 {	GradientPoll(Gradient::Stone, Gradient::None, 4), 
+			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 2), 
+			GradientPoll(Gradient::VillageCenter, Gradient::Resource, 1)}, //barracks
 
 		 {	GradientPoll(Gradient::VillageCenter, Gradient::Resource, 1), 
 			GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 2), 
-			GradientPoll()}, //school
+			GradientPoll(Gradient::Water, Gradient::None, 10, -1)}, //school
 
-		 {	GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 1),
-			GradientPoll(),
+		 {	GradientPoll(Gradient::TeamBuildings, Gradient::Resource, 3),
+			GradientPoll(Gradient::Stone, Gradient::None, 1),
 			GradientPoll()}, //Tower
 
 		 {	GradientPoll(), GradientPoll(), GradientPoll()},
@@ -1423,7 +1422,7 @@ namespace Nicowar
 	const unsigned int MAX_DISTANCE_FROM_WATER=8;
 
 	///This constant turns on debugging output
-	const bool AINicowar_DEBUG = true;
+	const bool AINicowar_DEBUG = false;
 	///@}
 
 	//These are just some handy functions
