@@ -68,12 +68,20 @@ Building::Building(int x, int y, Uint16 gid, Sint32 typeNum, Team *team, Buildin
 	
 
 	// units
-	maxUnitInside=type->maxUnitInside;
-	maxUnitWorking=type->maxUnitWorking;
-	maxUnitWorkingLocal=maxUnitWorking;
-	maxUnitWorkingPreferred=1;
-	subscriptionInsideTimer=0;
-	subscriptionWorkingTimer=0;
+	shortTypeNum = type->shortTypeNum;
+	maxUnitInside = type->maxUnitInside;
+	maxUnitWorking = type->maxUnitWorking;
+	maxUnitWorkingLocal = maxUnitWorking; //default for units not defined within settings
+	if (shortTypeNum == 9)
+		maxUnitWorkingLocal = globalContainer->settings.warflagUnit;
+	if (shortTypeNum == 10)
+		maxUnitWorkingLocal = globalContainer->settings.clearflagUnit;
+	if (shortTypeNum == 8)
+		maxUnitWorkingLocal = globalContainer->settings.exploreflagUnit;
+	maxUnitWorking = maxUnitWorkingLocal;
+	maxUnitWorkingPreferred = 1;
+	subscriptionInsideTimer = 0;
+	subscriptionWorkingTimer = 0;
 
 	// position
 	posX=x;
@@ -93,12 +101,14 @@ Building::Building(int x, int y, Uint16 gid, Sint32 typeNum, Team *team, Buildin
 	
 	// building specific :
 	for(int i=0; i<MAX_NB_RESSOURCES; i++)
-		ressources[i]=0;
+		localRessource[i]=0;
+	updateRessourcesPointer();
 
 	// quality parameters
 	hp=type->hpInit; // (Uint16)
 
 	// prefered parameters
+
 	productionTimeout=type->unitProductionTime;
 
 	totalRatio=0;
@@ -154,6 +164,34 @@ Building::Building(int x, int y, Uint16 gid, Sint32 typeNum, Team *team, Buildin
 	verbose=false;
 }
 
+Building::~Building()
+{
+	freeGradients();
+}
+
+void Building::freeGradients()
+{
+	for (int i=0; i<2; i++)
+	{
+		if (globalGradient[i])
+		{
+			delete[] globalGradient[i];
+			globalGradient[i] = NULL;
+		}
+		if (localRessources[i])
+		{
+			delete[] localRessources[i];
+			localRessources[i] = NULL;
+		}
+		dirtyLocalGradient[i] = true;
+		locked[i] = false;
+		lastGlobalGradientUpdateStepCounter[i] = 0;
+		
+		localRessourcesCleanTime[i] = 0;
+		anyRessourceToClear[i] = 0;
+	}
+}
+
 void Building::load(GAGCore::InputStream *stream, BuildingsTypes *types, Team *owner, Sint32 versionMinor)
 {
 	stream->readEnterSection("Building");
@@ -203,8 +241,8 @@ void Building::load(GAGCore::InputStream *stream, BuildingsTypes *types, Team *o
 	for (int i=0; i<MAX_NB_RESSOURCES; i++)
 	{
 		std::ostringstream oss;
-		oss << "ressources[" << i << "]";
-		ressources[i] = stream->readSint32(oss.str().c_str());
+		oss << "localRessource[" << i << "]";
+		localRessource[i] = stream->readSint32(oss.str().c_str());
 	}
 
 	// quality parameters
@@ -244,6 +282,25 @@ void Building::load(GAGCore::InputStream *stream, BuildingsTypes *types, Team *o
 	typeNum = stream->readSint32("typeNum");
 	type = types->get(typeNum);
 	assert(type);
+	updateRessourcesPointer();
+	
+	// reload data from type
+	shortTypeNum = type->shortTypeNum;
+	maxUnitInside = type->maxUnitInside;
+	maxUnitWorking = type->maxUnitWorking;
+	
+	// init data not loaded
+	maxUnitWorkingLocal = maxUnitWorking;
+	if (shortTypeNum == 9)
+		maxUnitWorkingLocal = globalContainer->settings.warflagUnit;
+	if (shortTypeNum == 10)
+		maxUnitWorkingLocal = globalContainer->settings.clearflagUnit;
+	if (shortTypeNum == 8)
+		maxUnitWorkingLocal = globalContainer->settings.exploreflagUnit;
+	maxUnitWorkingPreferred = 1;
+	subscriptionInsideTimer = 0;
+	subscriptionWorkingTimer = 0;
+	
 	owner->prestige += type->prestige;
 	
 	seenByMask = stream->readUint32("seenByMaskk");
@@ -263,25 +320,7 @@ void Building::load(GAGCore::InputStream *stream, BuildingsTypes *types, Team *o
 	for (int i=0; i<NB_ABILITY; i++)
 		upgrade[i] = 0;
 	
-	for (int i=0; i<2; i++)
-	{
-		if (globalGradient[i])
-		{
-			delete[] globalGradient[i];
-			globalGradient[i] = NULL;
-		}
-		if (localRessources[i])
-		{
-			delete[] localRessources[i];
-			localRessources[i] = NULL;
-		}
-		dirtyLocalGradient[i] = true;
-		locked[i] = false;
-		lastGlobalGradientUpdateStepCounter[i] = 0;
-		
-		localRessourcesCleanTime[i] = 0;
-		anyRessourceToClear[i] = 0;
-	}
+	freeGradients();
 	
 	verbose = false;
 	stream->readLeaveSection();
@@ -317,8 +356,8 @@ void Building::save(GAGCore::OutputStream *stream)
 	for (int i=0; i<MAX_NB_RESSOURCES; i++)
 	{
 		std::ostringstream oss;
-		oss << "ressources[" << i << "]";
-		stream->writeSint32(ressources[i], oss.str().c_str());
+		oss << "localRessource[" << i << "]";
+		stream->writeSint32(localRessource[i], oss.str().c_str());
 	}
 
 	// quality parameters
@@ -490,9 +529,11 @@ void Building::saveCrossRef(GAGCore::OutputStream *stream)
 
 bool Building::isRessourceFull(void)
 {
-	for (int i=0; i<BASIC_COUNT; i++)
+	for (int i=0; i<MAX_NB_RESSOURCES; i++)
+	{
 		if (ressources[i]+type->multiplierRessource[i]<=type->maxRessource[i])
 			return false;
+	}
 	return true;
 }
 
@@ -537,6 +578,19 @@ void Building::wishedRessources(int needs[MAX_NB_RESSOURCES])
 		}
 }
 
+void Building::computeWishedRessources()
+{
+	 // we balance the system with Units working on it:
+	for (int ri = 0; ri < MAX_NB_RESSOURCES; ri++)
+		wishedResources[ri] = (2 * (type->maxRessource[ri] - ressources[ri])) / (type->multiplierRessource[ri]);
+	for (std::list<Unit *>::iterator ui = unitsWorking.begin(); ui != unitsWorking.end(); ++ui)
+		if ((*ui)->destinationPurprose >= 0)
+		{
+			assert((*ui)->destinationPurprose < MAX_NB_RESSOURCES);
+			wishedResources[(*ui)->destinationPurprose]--;
+		}
+}
+
 int Building::neededRessource(int r)
 {
 	assert(r >= 0);
@@ -652,6 +706,9 @@ void Building::cancelConstruction(void)
 	type=recoverType;
 	owner->prestige+=type->prestige;
 	owner->addToStaticAbilitiesLists(this);
+
+	//Update the pointer ressources to the newly changed type
+	updateRessourcesPointer();
 	
 	posX=midPosX+type->decLeft;
 	posY=midPosY+type->decTop;
@@ -1031,6 +1088,10 @@ void Building::updateBuildingSite(void)
 		constructionResultState=NO_CONSTRUCTION;
 		owner->prestige+=type->prestige;
 
+		//Update the pointer ressources to the newly changed type
+		updateRessourcesPointer();
+	
+
 		// we don't need any worker any more
 
 		// Notice that we could avoid freeing thoses units,
@@ -1170,6 +1231,9 @@ bool Building::tryToBuildingSiteRoom(void)
 		type=targetBt;
 		owner->prestige+=type->prestige;
 
+		//Update the pointer ressources to the newly changed type
+		updateRessourcesPointer();
+	
 		buildingState=ALIVE;
 		owner->addToStaticAbilitiesLists(this);
 		
@@ -1809,6 +1873,7 @@ void Building::turretStep(void)
 	if (bullets <= 0)
 		return;
 
+	//for some reason, any turret that is not 2x2 makes no sense at all to the game
 	assert(type->width ==2);
 	assert(type->height==2);
 
@@ -1826,6 +1891,7 @@ void Building::turretStep(void)
 		TARGETTYPE_BUILDING,
 		TARGETTYPE_WORKER,
 		TARGETTYPE_WARRIOR,
+		TARGETTYPE_EXPLORER,
 	};
 	// The type of the best target we have found up to now
 	TargetType targetFound = TARGETTYPE_NONE;
@@ -1886,6 +1952,7 @@ void Building::turretStep(void)
 					break;
 				}
 				int targetGUID = map->getGroundUnit(targetX, targetY);
+				int airTargetGUID = map->getAirUnit(targetX, targetY);
 				if (targetGUID != NOGUID)
 				{
 					Sint32 otherTeam = Unit::GIDtoTeam(targetGUID);
@@ -1945,6 +2012,40 @@ void Building::turretStep(void)
 						}
 					}
 				}
+				//otherwise we shoot explorers - only after workers and warriors, for no particular reason
+				//(this maybe should be changed?)
+				//(this bit maybe should be merged into the above bit, due to being so similar?)
+				//(or made into a function?)
+				if (airTargetGUID != NOGUID && targetFound == TARGETTYPE_NONE)
+				{
+					Sint32 otherTeam = Unit::GIDtoTeam(airTargetGUID);
+					Sint32 targetID = Unit::GIDtoID(airTargetGUID);
+					Uint32 otherTeamMask = 1<<otherTeam;
+					if (enemies & otherTeamMask)
+					{
+						Unit *testUnit = owner->game->teams[otherTeam]->myUnits[targetID];
+						if ((owner->sharedVisionExchange & otherTeamMask) == 0)
+						{
+							int targetTicks = (256 - testUnit->delta) / testUnit->speed;
+							// skip this unit if it will move away too soon.
+							if (targetTicks <= ticksToHit)
+								continue;
+							//Using simple calculation for now (should always shoot ground-attackers first, probably)
+							// adjust score for range
+							int targetScore = - testUnit->hp;
+							// lower scores are overriden
+							if (targetScore > bestScore)
+							{
+								bestScore = targetScore;
+								bestTicks = targetTicks;
+								bestTargetX = targetX;
+								bestTargetY = targetY;
+								targetFound = TARGETTYPE_EXPLORER;
+							}
+						}
+					}
+				}
+
 				// shoot building only if no unit is found
 				if (targetFound == TARGETTYPE_NONE)
 				{
@@ -1973,6 +2074,7 @@ void Building::turretStep(void)
 		}
 		if (targetFound == TARGETTYPE_WARRIOR)
 			break;
+		//logic for this? well, we've found a good warrior to shoot at already, and they take priority...
 	}
 
 	if (targetFound != TARGETTYPE_NONE)
@@ -2098,6 +2200,9 @@ void Building::kill(void)
 	if (!type->isVirtual)
 	{
 		owner->map->setBuilding(posX, posY, type->width, type->height, NOGBID);
+		owner->dirtyGlobalGradient();
+		owner->map->updateForbiddenGradient(owner->teamNumber);
+		owner->map->updateGuardAreasGradient(owner->teamNumber);
 		if (type->isBuildingSite && type->level==0)
 		{
 			bool good=false;
@@ -2119,6 +2224,22 @@ void Building::kill(void)
 	owner->buildingsToBeDestroyed.push_front(this);
 }
 
+
+
+void Building::updateRessourcesPointer()
+{
+	if(!type->useTeamRessources)
+	{
+		ressources=localRessource;
+	}
+	else
+	{
+		ressources=owner->teamRessources;
+	}
+}
+
+
+
 int Building::getMidX(void)
 {
 	return ((posX-type->decLeft)&owner->map->getMaskW());
@@ -2459,7 +2580,7 @@ Uint32 Building::checkSum(std::vector<Uint32> *checkSumsVector)
 		checkSumsVector->push_back(cs);// [9]
 
 	for (int i=0; i<MAX_RESSOURCES; i++)
-		cs^=ressources[i];
+		cs^=localRessource[i];
 	if (checkSumsVector)
 		checkSumsVector->push_back(cs);// [10]
 	cs=(cs<<31)|(cs>>1);
