@@ -59,9 +59,17 @@ public:
 		UPGRADE=2,
 		REPAIR=3
 	};
+	
+	enum MatchPriority
+	{
+		MP_LOW    = 0x10000000,
+		MP_MEDIUM = 0x20000000,
+		MP_HIGH   = 0x30000000,
+	};
 
 	// type
 	Sint32 typeNum; // number in BuildingTypes
+	int shortTypeNum;
 	BuildingType *type;
 
 	// construction state
@@ -79,6 +87,7 @@ public:
 	std::list<Unit *> unitsInside;
 	std::list<Unit *> unitsInsideSubscribe;
 	Sint32 subscriptionInsideTimer;
+	MatchPriority matchPriority;
 	
 	// optimisation and consistency
 	// Included in {0: unknow, 1:allready in owner-><same name>, 2:not in owner-><same name>
@@ -109,8 +118,12 @@ public:
 	Sint32 minLevelToFlagLocal;
 
 	// Building specific :
-	/// Ammount stocked, or used for building building.
-	Sint32 ressources[MAX_NB_RESSOURCES];
+	/// Ammount stocked, or used for building building. Local ressources stores the ressources this particular building contains
+	/// in the event that the building type designates using global ressources instead of local ressources, the ressources pointer
+	/// will be changed to point to the global ressources Team::teamRessources instead of localRessources.
+	Sint32* ressources;
+	Sint32 wishedResources[MAX_NB_RESSOURCES];
+	Sint32 localRessource[MAX_NB_RESSOURCES];
 
 	// quality parameters
 	Sint32 hp; // (Uint16)
@@ -149,7 +162,8 @@ public:
 public:
 	Building(GAGCore::InputStream *stream, BuildingsTypes *types, Team *owner, Sint32 versionMinor);
 	Building(int x, int y, Uint16 gid, int typeNum, Team *team, BuildingsTypes *types);
-	virtual ~Building(void) { }
+	virtual ~Building(void);
+	void freeGradients();
 	
 	void load(GAGCore::InputStream *stream, BuildingsTypes *types, Team *owner, Sint32 versionMinor);
 	void save(GAGCore::OutputStream *stream);
@@ -160,6 +174,7 @@ public:
 	int neededRessource(void);
 	void neededRessources(int needs[MAX_NB_RESSOURCES]);
 	void wishedRessources(int needs[MAX_NB_RESSOURCES]);
+	void computeWishedRessources();
 	int neededRessource(int r);
 	void launchConstruction(void);
 	void cancelConstruction(void);
@@ -194,6 +209,8 @@ public:
 	void clearingFlagsStep(void);
 	void kill(void);
 
+	void updateRessourcesPointer();
+	
 	int getMidX(void);
 	int getMidY(void);
 	int getMaxUnitStayRange(void);
