@@ -47,6 +47,7 @@ public:
 	// by order of priority (top = max)
 	Sint32 upgrade[NB_ABILITY]; // What kind on units can be upgraded here
 	Sint32 upgradeTime[NB_ABILITY]; // Time to upgrade an unit, given the upgrade type needed.
+	Sint32 upgradeInParallel; // if true, can learn all upgardes with one learning time into the building
 	Sint32 foodable;
 	Sint32 fillable;
 	Sint32 zonable[NB_UNIT_TYPE]; // If an unit is required for a presence.
@@ -58,6 +59,7 @@ public:
 	Sint32 timeToHealUnit;
 	Sint32 insideSpeed;
 	Sint32 canExchange;
+	Sint32 useTeamRessources;
 
 	Sint32 width, height; // Uint8, size in square
 	Sint32 decLeft, decTop;
@@ -112,6 +114,7 @@ public:
 	BuildingType();
 	virtual ~BuildingType() { }
 	virtual void loadFromConfigFile(const ConfigBlock *configBlock);
+	Uint32 checkSum(void);
 };
 
 #endif
