@@ -21,6 +21,7 @@
 #include "GUIGlob2FileList.h"
 #include "GUIMapPreview.h"
 #include "Session.h"
+#include <FormatableString.h>
 #include <GUIButton.h>
 #include <GUIText.h>
 #include <Toolkit.h>
@@ -96,12 +97,12 @@ void ChooseMapScreen::onAction(Widget *source, Action action, int par1, int par2
 			{
 				// update map name & info
 				mapName->setText(sessionInfo.getMapName());
-				char textTemp[256];
-				snprintf(textTemp, 256, "%d%s", sessionInfo.numberOfTeam, Toolkit::getStringTable()->getString("[teams]"));
+				std::string textTemp;
+				textTemp = FormatableString("%0%1").arg(sessionInfo.numberOfTeam).arg(Toolkit::getStringTable()->getString("[teams]"));
 				mapInfo->setText(textTemp);
-				snprintf(textTemp, 256, "%s %d.%d", Toolkit::getStringTable()->getString("[Version]"), sessionInfo.versionMajor, sessionInfo.versionMinor);
+				textTemp = FormatableString("%0 %1.%2").arg(Toolkit::getStringTable()->getString("[Version]")).arg(sessionInfo.versionMajor).arg(sessionInfo.versionMinor);
 				mapVersion->setText(textTemp);
-				snprintf(textTemp, 256, "%d x %d", mapPreview->getLastWidth(), mapPreview->getLastHeight());
+				textTemp = FormatableString("%0 x %1").arg(mapPreview->getLastWidth()).arg(mapPreview->getLastHeight());
 				mapSize->setText(textTemp);
 				std::time_t mtime = Toolkit::getFileManager()->mtime(mapFileName);
 				mapDate->setText(std::ctime(&mtime));
