@@ -57,7 +57,7 @@ using namespace GAGCore;
 	public:
 		ScrollingText(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *font, const char *filename);
 		virtual ~ScrollingText() { }
-		virtual void init(void);
+		virtual void internalInit(void);
 		virtual void paint(void);
 		virtual void onTimer(Uint32 tick);
 	};
@@ -104,7 +104,7 @@ ScrollingText::ScrollingText(int x, int y, int w, int h, Uint32 hAlign, Uint32 v
 	delete inputLineStream;
 }
 
-void ScrollingText::init(void)
+void ScrollingText::internalInit(void)
 {
 	fontPtr = Toolkit::getFont(font.c_str());
 	assert(fontPtr);
