@@ -18,7 +18,7 @@
 */
 
 #include "EndGameScreen.h"
-#include <algorithm>
+#include <FormatableString.h>
 #include <GUIText.h>
 #include <GUIButton.h>
 #include <Toolkit.h>
@@ -57,12 +57,19 @@ void EndGameStat::paint(void)
 	// draw background
 	parent->getSurface()->drawRect(x, y, w, h, ColorTheme::frontFrameColor);
 	
+	if(game->teams[0]->stats.endOfGameStats.size()==0)
+		return;
 	// find maximum
-	int team, pos, maxValue = 1;
+	int team, maxValue = 0;
+	unsigned int pos=0;
 	for (team=0; team < game->session.numberOfTeam; team++)
-		for (pos=0; pos<TeamStats::END_OF_GAME_STATS_SIZE; pos++)
+		for (pos=0; pos<game->teams[team]->stats.endOfGameStats.size(); pos++)
 			maxValue = std::max(maxValue, game->teams[team]->stats.endOfGameStats[pos].value[type]);
 	
+
+	float inc_x=static_cast<float>(w-2)/static_cast<float>(game->teams[0]->stats.endOfGameStats.size()-1);
+	float inc_y=static_cast<float>(h-2)/static_cast<float>(maxValue);
+
 	// draw curve
 	if (maxValue)
 	{
@@ -72,17 +79,16 @@ void EndGameStat::paint(void)
 			Uint8 g = game->teams[team]->colorG;
 			Uint8 b = game->teams[team]->colorB;
 
-			int statsIndex = game->teams[team]->stats.endOfGameStatIndex;
+			int statsIndex = 0;
 			int oy, ox, nx, ny;
 
 			ox = 1;
-			oy = (game->teams[team]->stats.endOfGameStats[statsIndex].value[type] * (h-2))/maxValue;
+			oy = static_cast<int>(game->teams[team]->stats.endOfGameStats[statsIndex].value[type] * inc_y);
 
-			for (pos=1; pos<TeamStats::END_OF_GAME_STATS_SIZE; pos++)
+			for (pos=0; pos<game->teams[team]->stats.endOfGameStats.size(); pos++)
 			{
-				int index=(statsIndex+pos)&0x7F;
-				nx = (pos*(w-2))/TeamStats::END_OF_GAME_STATS_SIZE;
-				ny = (game->teams[team]->stats.endOfGameStats[index].value[type] * (h-2))/maxValue;
+				nx = static_cast<int>(pos*inc_x);
+				ny = static_cast<int>(game->teams[team]->stats.endOfGameStats[pos].value[type] * inc_y);
 
 				parent->getSurface()->drawLine(x+ox, y+h-oy-1, x+nx, y+h-ny-1, r, g, b);
 
@@ -107,8 +113,7 @@ struct MoreScore : public std::binary_function<const TeamEntry&, const TeamEntry
 EndGameScreen::EndGameScreen(GameGUI *gui)
 {
 	// title & graph
-	const char *titleText;
-	char *allocatedText=NULL;
+	std::string titleText;
 	
 	if (gui->game.totalPrestigeReached)
 	{
@@ -120,19 +125,16 @@ EndGameScreen::EndGameScreen(GameGUI *gui)
 		}
 		else
 		{
-			const char *strText;
+			FormatableString strText;
 			if ((t->allies) & (gui->getLocalTeam()->me))
-				strText = Toolkit::getStringTable()->getString("[Won : your ally %s has the most prestige]");
+				strText = Toolkit::getStringTable()->getString("[Won : your ally %0 has the most prestige]");
 			else
-				strText = Toolkit::getStringTable()->getString("[Lost : %s has more prestige than you]");
+				strText = Toolkit::getStringTable()->getString("[Lost : %0 has more prestige than you]");
 
 			const char *playerText = t->getFirstPlayerName();
-			assert(strText);
 			assert(playerText);
-			int len=strlen(strText)+strlen(playerText)-1;
-			allocatedText=new char[len];
-			snprintf(allocatedText, len, strText, playerText);
-			titleText=allocatedText;
+			strText.arg(playerText);
+			titleText = strText;
 		}
 	}
 	else if (!gui->getLocalTeam()->isAlive)
@@ -148,9 +150,7 @@ EndGameScreen::EndGameScreen(GameGUI *gui)
 		titleText=Toolkit::getStringTable()->getString("[Won : you defeated your opponents]");
 	}
 	
-	addWidget(new Text(0, 18, ALIGN_FILL, ALIGN_LEFT, "menu", titleText));
-	if (allocatedText)
-		delete[] allocatedText;
+	addWidget(new Text(0, 18, ALIGN_FILL, ALIGN_LEFT, "menu", titleText.c_str()));
 	statWidget=new EndGameStat(20, 80, 180, 150, ALIGN_FILL, ALIGN_FILL, &(gui->game));
 	addWidget(statWidget);
 	
@@ -171,8 +171,7 @@ EndGameScreen::EndGameScreen(GameGUI *gui)
 	for (int i=0; i<gui->game.session.numberOfTeam; i++)
 	{
 		Team *t=gui->game.teams[i];
-		int statsIndex = t->stats.endOfGameStatIndex;
-		int endIndex=(statsIndex+(TeamStats::END_OF_GAME_STATS_SIZE-1))&0x7F;
+		int endIndex=t->stats.endOfGameStats.size()-1;
 
 		struct TeamEntry entry;
 		entry.name=t->getFirstPlayerName();
