@@ -41,6 +41,7 @@
 #include "LogFileManager.h"
 #include "Order.h"
 #include "Unit.h"
+#include "UnitSkin.h"
 #include "Utilities.h"
 
 #include "Brush.h"
@@ -63,6 +64,7 @@ Game::~Game()
 		sum+=ticksGameSum[i];
 	if (sum)
 	{
+		fprintf(logFile, "(sync)stepCounter=%d\n", stepCounter);
 		fprintf(logFile, "execution time of Game::step: sum=%d\n", sum);
 		for (int i=0; i<32; i++)
 			fprintf(logFile, "ticksGameSum[%2d]=%8d, (%f %%)\n", i, ticksGameSum[i], (float)ticksGameSum[i]*100./(float)sum);
@@ -247,7 +249,7 @@ void Game::executeOrder(Order *order, int localPlayer)
 			if ((b) && (b->buildingState==Building::ALIVE))
 			{
 				fprintf(logFile, "ORDER_MODIFY_BUILDING");
-				assert(omb->numberRequested <= 20 && omb->numberRequested >= 0);
+				assert(omb->numberRequested <= 20);
 				b->maxUnitWorking=omb->numberRequested;
 				b->maxUnitWorkingPreferred=b->maxUnitWorking;
 				if (order->sender!=localPlayer)
@@ -809,163 +811,150 @@ bool Game::load(GAGCore::InputStream *stream)
 		return false;
 	}
 
-	if (tempSessionInfo.mapGenerationDescriptor && tempSessionInfo.fileIsAMap)
-	{
-		tempSessionInfo.mapGenerationDescriptor->synchronizeNow();
-		if (!generateMap(*tempSessionInfo.mapGenerationDescriptor))
-		{
-			fprintf(logFile, "Game::load::generateMap\n");
-			stream->readLeaveSection();
-			return false;
-		}
-	}
-	else
-	{
-		session=(SessionGame)tempSessionInfo;
+	session=(SessionGame)tempSessionInfo;
 
-		if (stream->canSeek())
-			stream->seekFromStart(tempSessionInfo.gameOffset);
+	if (stream->canSeek())
+		stream->seekFromStart(tempSessionInfo.gameOffset);
 
-		char signature[4];
-		stream->read(signature, 4, "signatureStart");
-		if (session.versionMinor >= 31)
-		{
-			if (memcmp(signature,"GaBe", 4)!=0)
-			{
-				fprintf(logFile, "Signature missmatch at begin\n");
-				stream->readLeaveSection();
-				return false;
-			}
-		}
-		else if (memcmp(signature, "GAMb",4)!=0)
+	char signature[4];
+	stream->read(signature, 4, "signatureStart");
+	if (session.versionMinor >= 31)
+	{
+		if (memcmp(signature,"GaBe", 4)!=0)
 		{
 			fprintf(logFile, "Signature missmatch at begin\n");
 			stream->readLeaveSection();
 			return false;
 		}
-		
-		if (session.versionMinor>=31)
-			stepCounter = stream->readUint32("stepCounter");
-		setSyncRandSeedA(stream->readUint32("SyncRandSeedA"));
-		setSyncRandSeedB(stream->readUint32("SyncRandSeedB"));
-		setSyncRandSeedC(stream->readUint32("SyncRandSeedC"));
+	}
+	else if (memcmp(signature, "GAMb",4)!=0)
+	{
+		fprintf(logFile, "Signature missmatch at begin\n");
+		stream->readLeaveSection();
+		return false;
+	}
+	
+	if (session.versionMinor>=31)
+		stepCounter = stream->readUint32("stepCounter");
+	setSyncRandSeedA(stream->readUint32("SyncRandSeedA"));
+	setSyncRandSeedB(stream->readUint32("SyncRandSeedB"));
+	setSyncRandSeedC(stream->readUint32("SyncRandSeedC"));
 
-		stream->read(signature, 4, "signatureAfterSyncRand");
-		if (session.versionMinor>=31)
-		{
-			if (memcmp(signature,"GaSy", 4)!=0)
-			{
-				fprintf(logFile, "Signature missmatch after sync rand\n");
-				stream->readLeaveSection();
-				return false;
-			}
-		}
-		else if (memcmp(signature, "GAMm", 4)!=0)
+	stream->read(signature, 4, "signatureAfterSyncRand");
+	if (session.versionMinor>=31)
+	{
+		if (memcmp(signature,"GaSy", 4)!=0)
 		{
 			fprintf(logFile, "Signature missmatch after sync rand\n");
 			stream->readLeaveSection();
 			return false;
 		}
-
-		// we load teams
-		if (stream->canSeek())
-			stream->seekFromStart(tempSessionInfo.teamsOffset);
-		stream->readEnterSection("teams");
-		for (int i=0; i<session.numberOfTeam; ++i)
-		{
-			stream->readEnterSection(i);
-			teams[i]=new Team(stream, this, session.versionMinor);
-			stream->readLeaveSection();
-		}
+	}
+	else if (memcmp(signature, "GAMm", 4)!=0)
+	{
+		fprintf(logFile, "Signature missmatch after sync rand\n");
 		stream->readLeaveSection();
-		if (session.versionMinor>=31)
+		return false;
+	}
+
+	// we load teams
+	if (stream->canSeek())
+		stream->seekFromStart(tempSessionInfo.teamsOffset);
+	stream->readEnterSection("teams");
+	for (int i=0; i<session.numberOfTeam; ++i)
+	{
+		stream->readEnterSection(i);
+		teams[i]=new Team(stream, this, session.versionMinor);
+		stream->readLeaveSection();
+	}
+	stream->readLeaveSection();
+	if (session.versionMinor>=31)
+	{
+		stream->read(signature, 4, "signatureAfterTeams");
+		if (memcmp(signature,"GaTe", 4)!=0)
 		{
-			stream->read(signature, 4, "signatureAfterTeams");
-			if (memcmp(signature,"GaTe", 4)!=0)
-			{
-				fprintf(logFile, "Signature missmatch after teams\n");
-				stream->readLeaveSection();
-				return false;
-			}
-		}
-		
-		// we have to load team before map
-		if (stream->canSeek())
-			stream->seekFromStart(tempSessionInfo.mapOffset);
-		if(!map.load(stream, &session, this))
-		{
-			fprintf(logFile, "Signature missmatch in map\n");
+			fprintf(logFile, "Signature missmatch after teams\n");
 			stream->readLeaveSection();
 			return false;
 		}
-		stream->read(signature, 4, "signatureAfterMap");
-		if (session.versionMinor>=31)
-		{
-			if (memcmp(signature,"GaMa", 4)!=0)
-			{
-				fprintf(logFile, "Signature missmatch after map\n");
-				stream->readLeaveSection();
-				return false;
-			}
-		}
-		else if (memcmp(signature,"GAMe", 4)!=0)
+	}
+	
+	// we have to load team before map
+	if (stream->canSeek())
+		stream->seekFromStart(tempSessionInfo.mapOffset);
+	if(!map.load(stream, &session, this))
+	{
+		fprintf(logFile, "Signature missmatch in map\n");
+		stream->readLeaveSection();
+		return false;
+	}
+	stream->read(signature, 4, "signatureAfterMap");
+	if (session.versionMinor>=31)
+	{
+		if (memcmp(signature,"GaMa", 4)!=0)
 		{
 			fprintf(logFile, "Signature missmatch after map\n");
 			stream->readLeaveSection();
 			return false;
 		}
-
-		// we have to load map and team before players
-		if (stream->canSeek())
-			stream->seekFromStart(tempSessionInfo.playersOffset);
-		stream->readEnterSection("players");
-		for (int i=0; i<session.numberOfPlayer; ++i)
-		{
-			stream->readEnterSection(i);
-			players[i]=new Player(stream, teams, session.versionMinor);
-			stream->readLeaveSection();
-		}
+	}
+	else if (memcmp(signature,"GAMe", 4)!=0)
+	{
+		fprintf(logFile, "Signature missmatch after map\n");
 		stream->readLeaveSection();
-		
-		if (session.versionMinor>=31)
-		{
-			stream->read(signature, 4, "signatureAfterPlayers");
-			if (memcmp(signature,"GaPl", 4)!=0)
-			{
-				fprintf(logFile, "Signature missmatch after players\n");
-				stream->readLeaveSection();
-				return false;
-			}
-		}
-		else
-			stepCounter = stream->readUint32("stepCounter");
+		return false;
+	}
 
-		// we have to finish Team's loading:
-		for (int i=0; i<session.numberOfTeam; i++)
-			teams[i]->update();
-		
-		for (int i=0; i<session.numberOfTeam; i++)
-			teams[i]->integrity();
-		
-		// then script
-		if (stream->canSeek())
-			stream->seekFromStart(tempSessionInfo.mapScriptOffset);
-		if (!script.load(stream, this))
+	// we have to load map and team before players
+	if (stream->canSeek())
+		stream->seekFromStart(tempSessionInfo.playersOffset);
+	stream->readEnterSection("players");
+	for (int i=0; i<session.numberOfPlayer; ++i)
+	{
+		stream->readEnterSection(i);
+		players[i]=new Player(stream, teams, session.versionMinor);
+		stream->readLeaveSection();
+	}
+	stream->readLeaveSection();
+	
+	if (session.versionMinor>=31)
+	{
+		stream->read(signature, 4, "signatureAfterPlayers");
+		if (memcmp(signature,"GaPl", 4)!=0)
 		{
+			fprintf(logFile, "Signature missmatch after players\n");
 			stream->readLeaveSection();
 			return false;
 		}
-		
-		if (session.versionMinor < 37)
-		{
-			nextMap = "";
-			campaignText = "";
-		}
-		else
-		{
-			nextMap = stream->readText("nextMap");
-			campaignText = stream->readText("campaignText");
-		}
+	}
+	else
+		stepCounter = stream->readUint32("stepCounter");
+
+	// we have to finish Team's loading:
+	for (int i=0; i<session.numberOfTeam; i++)
+		teams[i]->update();
+	
+	for (int i=0; i<session.numberOfTeam; i++)
+		teams[i]->integrity();
+	
+	// then script
+	if (stream->canSeek())
+		stream->seekFromStart(tempSessionInfo.mapScriptOffset);
+	if (!script.load(stream, this))
+	{
+		stream->readLeaveSection();
+		return false;
+	}
+	
+	if (session.versionMinor < 37)
+	{
+		nextMap = "";
+		campaignText = "";
+	}
+	else
+	{
+		nextMap = stream->readText("nextMap");
+		campaignText = stream->readText("campaignText");
 	}
 
 	// Compute new max prestige
@@ -1002,55 +991,47 @@ void Game::save(GAGCore::OutputStream *stream, bool fileIsAMap, const char* name
 	
 	tempSessionInfo.save(stream);
 	
-	if (session.mapGenerationDescriptor && session.fileIsAMap)
+	SAVE_OFFSET(stream, 16, "gameOffset");
+	stream->write("GaBe", 4, "signatureStart");
+
+	stream->writeUint32(stepCounter, "stepCounter");
+	stream->writeUint32(getSyncRandSeedA(), "SyncRandSeedA");
+	stream->writeUint32(getSyncRandSeedB(), "SyncRandSeedB");
+	stream->writeUint32(getSyncRandSeedC(), "SyncRandSeedC");
+	stream->write("GaSy", 4, "signatureAfterSyncRand");
+
+	SAVE_OFFSET(stream, 20, "teamsOffset");
+	stream->writeEnterSection("teams");
+	for (int i=0; i<session.numberOfTeam; ++i)
 	{
-		// In this case, the map is fully determinated by the mapGenerationDescriptor.
-		//printf("giga compression system activated.\n");
+		stream->writeEnterSection(i);
+		teams[i]->save(stream);
+		stream->writeLeaveSection();
 	}
-	else
+	stream->writeLeaveSection();
+	stream->write("GaTe", 4, "signatureAfterTeams");
+
+	SAVE_OFFSET(stream, 28, "mapOffset");
+	map.save(stream);
+	stream->write("GaMa", 4, "signatureAfterMap");
+		
+	SAVE_OFFSET(stream, 24, "playersOffset");
+	stream->writeEnterSection("players");
+	for (int i=0; i<session.numberOfPlayer; ++i)
 	{
-		SAVE_OFFSET(stream, 16, "gameOffset");
-		stream->write("GaBe", 4, "signatureStart");
-
-		stream->writeUint32(stepCounter, "stepCounter");
-		stream->writeUint32(getSyncRandSeedA(), "SyncRandSeedA");
-		stream->writeUint32(getSyncRandSeedB(), "SyncRandSeedB");
-		stream->writeUint32(getSyncRandSeedC(), "SyncRandSeedC");
-		stream->write("GaSy", 4, "signatureAfterSyncRand");
-
-		SAVE_OFFSET(stream, 20, "teamsOffset");
-		stream->writeEnterSection("teams");
-		for (int i=0; i<session.numberOfTeam; ++i)
-		{
-			stream->writeEnterSection(i);
-			teams[i]->save(stream);
-			stream->writeLeaveSection();
-		}
+		stream->writeEnterSection(i);
+		players[i]->save(stream);
 		stream->writeLeaveSection();
-		stream->write("GaTe", 4, "signatureAfterTeams");
-
-		SAVE_OFFSET(stream, 28, "mapOffset");
-		map.save(stream);
-		stream->write("GaMa", 4, "signatureAfterMap");
-		
-		SAVE_OFFSET(stream, 24, "playersOffset");
-		stream->writeEnterSection("players");
-		for (int i=0; i<session.numberOfPlayer; ++i)
-		{
-			stream->writeEnterSection(i);
-			players[i]->save(stream);
-			stream->writeLeaveSection();
-		}
-		stream->writeLeaveSection();
-		stream->write("GaPl", 4, "signatureAfterPlayers");
-
-		SAVE_OFFSET(stream, 32, "mapScriptOffset");
-		script.save(stream, this);
-		
-		stream->writeText(nextMap, "nextMap");
-		stream->writeText(campaignText, "campaignText");
 	}
 	stream->writeLeaveSection();
+	stream->write("GaPl", 4, "signatureAfterPlayers");
+
+	SAVE_OFFSET(stream, 32, "mapScriptOffset");
+	script.save(stream, this);
+	
+	stream->writeText(nextMap, "nextMap");
+	stream->writeText(campaignText, "campaignText");
+	stream->writeLeaveSection();
 }
 
 void Game::buildProjectSyncStep(Sint32 localTeam)
@@ -1214,20 +1195,28 @@ void Game::syncStep(Sint32 localTeam)
 	}
 }
 
-void Game::addTeam(void)
+void Game::dirtyWarFlagGradient(void)
 {
+	for (int i=0; i<session.numberOfTeam; i++)
+		teams[i]->dirtyWarFlagGradient();
+}
+
+void Game::addTeam(int pos)
+{
+	if(pos==-1)
+		pos=session.numberOfTeam;
 	if (session.numberOfTeam<32)
 	{
-		teams[session.numberOfTeam]=new Team(this);
-		teams[session.numberOfTeam]->teamNumber=session.numberOfTeam;
-		teams[session.numberOfTeam]->race.load();
-		teams[session.numberOfTeam]->setCorrectMasks();
+		teams[pos]=new Team(this);
+		teams[pos]->teamNumber=session.numberOfTeam;
+		teams[pos]->race.load();
+		teams[pos]->setCorrectMasks();
 
-		session.numberOfTeam++;
-		for (int i=0; i<session.numberOfTeam; i++)
-			teams[i]->setCorrectColor( ((float)i*360.0f) /(float)session.numberOfTeam );
+		pos=++session.numberOfTeam;
+		for (int i=0; i<pos; i++)
+			teams[i]->setCorrectColor( ((float)i*360.0f) /(float)pos );
 		
-		prestigeToReach = std::max(MIN_MAX_PRESIGE, session.numberOfTeam*TEAM_MAX_PRESTIGE);
+		prestigeToReach = std::max(MIN_MAX_PRESIGE, pos*TEAM_MAX_PRESTIGE);
 		
 		map.addTeam();
 	}
@@ -1235,21 +1224,23 @@ void Game::addTeam(void)
 		assert(false);
 }
 
-void Game::removeTeam(void)
+void Game::removeTeam(int pos)
 {
+	if(pos==-1)
+		pos=--session.numberOfTeam;
 	if (session.numberOfTeam>0)
 	{
-		Team *team=teams[--session.numberOfTeam];
+		Team *team=teams[pos];
 
 		team->clearMap();
 
 		delete team;
-
 		assert (session.numberOfTeam!=0);
 		for (int i=0; i<session.numberOfTeam; ++i)
 			teams[i]->setCorrectColor(((float)i*360.0f)/(float)session.numberOfTeam);
 
 		map.removeTeam();
+		teams[pos]=NULL;
 	}
 }
 
@@ -1591,10 +1582,9 @@ void Game::drawUnit(int x, int y, Uint16 gid, int viewportX, int viewportY, int
 			return;
 
 	int imgid;
-	UnitType *ut=unit->race->getUnitType(unit->typeNum, 0);
 	assert(unit->action>=0);
 	assert(unit->action<NB_MOVE);
-	imgid=ut->startImage[unit->action];
+	imgid=unit->skin->startImage[unit->action];
 	int px, py;
 	map.mapCaseToDisplayable(unit->posX, unit->posY, &px, &py, viewportX, viewportY);
 	int deltaLeft=255-unit->delta;
@@ -1625,7 +1615,7 @@ void Game::drawUnit(int x, int y, Uint16 gid, int viewportX, int viewportY, int
 	}
 
 	// draw unit
-	Sprite *unitSprite=globalContainer->units;
+	Sprite *unitSprite = unit->skin->sprite;
 	unitSprite->setBaseColor(teams[team]->colorR, teams[team]->colorG, teams[team]->colorB);
 	int decX = (unitSprite->getW(imgid)-32)>>1;
 	int decY = (unitSprite->getH(imgid)-32)>>1;
@@ -2144,7 +2134,63 @@ void Game::drawMap(int sx, int sy, int sw, int sh, int viewportX, int viewportY,
 			globalContainer->gfx->drawString(accessX, accessY, globalContainer->littleFont, oss.str());
 		}
 	}
-	
+		
+	// draw forbidden and guard areas
+	if ((drawOptions & DRAW_AREA) != 0)
+		for (int y=top; y<bot; y++)
+			for (int x=left; x<right; x++)
+			{
+				if (map.isForbiddenLocal(x+viewportX, y+viewportY))
+				{
+					globalContainer->gfx->drawLine((x<<5), (y<<5), 32+(x<<5), 32+(y<<5), 128, 0, 0);
+					globalContainer->gfx->drawLine(16+(x<<5), (y<<5), 32+(x<<5), 16+(y<<5), 128, 0, 0);
+					globalContainer->gfx->drawLine((x<<5), 16+(y<<5), 16+(x<<5), 32+(y<<5), 128, 0, 0);
+					
+					if (!map.isForbiddenLocal(x+viewportX, y+viewportY-1))
+						globalContainer->gfx->drawHorzLine((x<<5), (y<<5), 32, 255, 0, 0);
+					if (!map.isForbiddenLocal(x+viewportX, y+viewportY+1))
+						globalContainer->gfx->drawHorzLine((x<<5), 32+(y<<5), 32, 255, 0, 0);
+					
+					if (!map.isForbiddenLocal(x+viewportX-1, y+viewportY))
+						globalContainer->gfx->drawVertLine((x<<5), (y<<5), 32, 255, 0, 0);
+					if (!map.isForbiddenLocal(x+viewportX+1, y+viewportY))
+						globalContainer->gfx->drawVertLine(32+(x<<5), (y<<5), 32, 255, 0, 0);
+				}
+				if (map.isGuardAreaLocal(x+viewportX, y+viewportY))
+				{
+					globalContainer->gfx->drawLine(32+(x<<5), (y<<5), (x<<5), 32+(y<<5), 0, 0, 128);
+					globalContainer->gfx->drawLine(16+(x<<5), (y<<5), (x<<5), 16+(y<<5), 0, 0, 128);
+					globalContainer->gfx->drawLine(32+(x<<5), 16+(y<<5), 16+(x<<5), 32+(y<<5), 0, 0, 128);
+					
+					if (!map.isGuardAreaLocal(x+viewportX, y+viewportY-1))
+						globalContainer->gfx->drawHorzLine((x<<5), (y<<5), 32, 0, 0, 255);
+					if (!map.isGuardAreaLocal(x+viewportX, y+viewportY+1))
+						globalContainer->gfx->drawHorzLine((x<<5), 32+(y<<5), 32, 0, 0, 255);
+					
+					if (!map.isGuardAreaLocal(x+viewportX-1, y+viewportY))
+						globalContainer->gfx->drawVertLine((x<<5), (y<<5), 32, 0, 0, 255);
+					if (!map.isGuardAreaLocal(x+viewportX+1, y+viewportY))
+						globalContainer->gfx->drawVertLine(32+(x<<5), (y<<5), 32, 0, 0, 255);
+				}
+				if (map.isClearAreaLocal(x+viewportX, y+viewportY))
+				{
+					globalContainer->gfx->drawLine(16+(x<<5), (y<<5), 16+(x<<5), 32+(y<<5), 64, 64, 0);
+					globalContainer->gfx->drawLine(32+(x<<5), (y<<5), 32+(x<<5), 32+(y<<5), 64, 64, 0);
+					//globalContainer->gfx->drawLine(8+(x<<5), (y<<5), 8+(x<<5), 32+(y<<5), 128, 128, 0);
+					//globalContainer->gfx->drawLine(24+(x<<5), (y<<5), 24+(x<<5), 32+(y<<5), 128, 128, 0);
+					
+					if (!map.isClearAreaLocal(x+viewportX, y+viewportY-1))
+						globalContainer->gfx->drawHorzLine((x<<5), (y<<5), 32, 128, 128, 0);
+					if (!map.isClearAreaLocal(x+viewportX, y+viewportY+1))
+						globalContainer->gfx->drawHorzLine((x<<5), 32+(y<<5), 32, 128, 128, 0);
+					
+					if (!map.isClearAreaLocal(x+viewportX-1, y+viewportY))
+						globalContainer->gfx->drawVertLine((x<<5), (y<<5), 32, 128, 128, 0);
+					if (!map.isClearAreaLocal(x+viewportX+1, y+viewportY))
+						globalContainer->gfx->drawVertLine(32+(x<<5), (y<<5), 32, 128, 128, 0);
+				}
+			}
+
 	
 	// We draw air units:
 	for (int y=top-1; y<=bot; y++)
@@ -2279,62 +2325,6 @@ void Game::drawMap(int sx, int sy, int sw, int sh, int viewportX, int viewportY,
 				}
 			}
 	}
-	
-	// draw forbidden and guard areas
-	if ((drawOptions & DRAW_AREA) != 0)
-		for (int y=top; y<bot; y++)
-			for (int x=left; x<right; x++)
-			{
-				if (map.isForbiddenLocal(x+viewportX, y+viewportY))
-				{
-					globalContainer->gfx->drawLine((x<<5), (y<<5), 32+(x<<5), 32+(y<<5), 128, 0, 0);
-					globalContainer->gfx->drawLine(16+(x<<5), (y<<5), 32+(x<<5), 16+(y<<5), 128, 0, 0);
-					globalContainer->gfx->drawLine((x<<5), 16+(y<<5), 16+(x<<5), 32+(y<<5), 128, 0, 0);
-					
-					if (!map.isForbiddenLocal(x+viewportX, y+viewportY-1))
-						globalContainer->gfx->drawHorzLine((x<<5), (y<<5), 32, 255, 0, 0);
-					if (!map.isForbiddenLocal(x+viewportX, y+viewportY+1))
-						globalContainer->gfx->drawHorzLine((x<<5), 32+(y<<5), 32, 255, 0, 0);
-					
-					if (!map.isForbiddenLocal(x+viewportX-1, y+viewportY))
-						globalContainer->gfx->drawVertLine((x<<5), (y<<5), 32, 255, 0, 0);
-					if (!map.isForbiddenLocal(x+viewportX+1, y+viewportY))
-						globalContainer->gfx->drawVertLine(32+(x<<5), (y<<5), 32, 255, 0, 0);
-				}
-				if (map.isGuardAreaLocal(x+viewportX, y+viewportY))
-				{
-					globalContainer->gfx->drawLine(32+(x<<5), (y<<5), (x<<5), 32+(y<<5), 0, 0, 128);
-					globalContainer->gfx->drawLine(16+(x<<5), (y<<5), (x<<5), 16+(y<<5), 0, 0, 128);
-					globalContainer->gfx->drawLine(32+(x<<5), 16+(y<<5), 16+(x<<5), 32+(y<<5), 0, 0, 128);
-					
-					if (!map.isGuardAreaLocal(x+viewportX, y+viewportY-1))
-						globalContainer->gfx->drawHorzLine((x<<5), (y<<5), 32, 0, 0, 255);
-					if (!map.isGuardAreaLocal(x+viewportX, y+viewportY+1))
-						globalContainer->gfx->drawHorzLine((x<<5), 32+(y<<5), 32, 0, 0, 255);
-					
-					if (!map.isGuardAreaLocal(x+viewportX-1, y+viewportY))
-						globalContainer->gfx->drawVertLine((x<<5), (y<<5), 32, 0, 0, 255);
-					if (!map.isGuardAreaLocal(x+viewportX+1, y+viewportY))
-						globalContainer->gfx->drawVertLine(32+(x<<5), (y<<5), 32, 0, 0, 255);
-				}
-				if (map.isClearAreaLocal(x+viewportX, y+viewportY))
-				{
-					globalContainer->gfx->drawLine(16+(x<<5), (y<<5), 16+(x<<5), 32+(y<<5), 64, 64, 0);
-					globalContainer->gfx->drawLine(32+(x<<5), (y<<5), 32+(x<<5), 32+(y<<5), 64, 64, 0);
-					//globalContainer->gfx->drawLine(8+(x<<5), (y<<5), 8+(x<<5), 32+(y<<5), 128, 128, 0);
-					//globalContainer->gfx->drawLine(24+(x<<5), (y<<5), 24+(x<<5), 32+(y<<5), 128, 128, 0);
-					
-					if (!map.isClearAreaLocal(x+viewportX, y+viewportY-1))
-						globalContainer->gfx->drawHorzLine((x<<5), (y<<5), 32, 128, 128, 0);
-					if (!map.isClearAreaLocal(x+viewportX, y+viewportY+1))
-						globalContainer->gfx->drawHorzLine((x<<5), 32+(y<<5), 32, 128, 128, 0);
-					
-					if (!map.isClearAreaLocal(x+viewportX-1, y+viewportY))
-						globalContainer->gfx->drawVertLine((x<<5), (y<<5), 32, 128, 128, 0);
-					if (!map.isClearAreaLocal(x+viewportX+1, y+viewportY))
-						globalContainer->gfx->drawVertLine(32+(x<<5), (y<<5), 32, 128, 128, 0);
-				}
-			}
 
 	// we look on the whole map for buildings
 	// TODO : increase speed, do not count on graphic clipping
