@@ -107,11 +107,13 @@ public:
 	void clearEventsStep(void);
 	//! called by gui, execute a step for this game. The gui parameter is for the script
 	void syncStep(Sint32 localTeam);
+	
+	void dirtyWarFlagGradient();
 
 	// Editor stuff
 	// add & remove teams, used by the map editor and the random map generator
-	void addTeam(void);
-	void removeTeam(void);
+	void addTeam(int pos=-1);
+	void removeTeam(int pos=-1);
 	//! If a team is uncontrolled (playerMask == 0), remove units and buildings from map
 	void clearingUncontrolledTeams(void);
 	void regenerateDiscoveryMap(void);
