@@ -61,6 +61,7 @@ public:
 	bool gamePaused;
 	bool hardPause;
 	bool isRunning;
+	bool notmenu;
 	//! true if user close the glob2 window.
 	bool exitGlobCompletely;
 	//! if this is not empty, then Engine should load the map with this filename.
@@ -321,7 +322,7 @@ private:
 	void setMultiLine(const std::string &input, std::vector<std::string> *output);
 
 	//! add a message to the window message list
-	void addMessage(Uint8 r, Uint8 g, Uint8 b, const char *msgText, ...);
+	void addMessage(Uint8 r, Uint8 g, Uint8 b, const std::string &msgText);
 	
 	// Typing stuff :
 	InGameTextInput *typingInputScreen;
