@@ -101,20 +101,21 @@ void Glob2::mutiplayerYOG(void)
 
 int Glob2::runNoX()
 {
-	Engine engine;
-	if (engine.initCustom(globalContainer->runNoXGameName)==Engine::EE_NO_ERROR)
+	printf("nox::running %d times %d steps:\n", globalContainer->runNoXCountRuns, globalContainer->runNoXCountSteps);
+	for (int runNoXCount = 0; runNoXCount < globalContainer->runNoXCountRuns; runNoXCount++)
 	{
+		Engine engine;
+		if (engine.initCustom(globalContainer->runNoXGameName) != Engine::EE_NO_ERROR)
+			return 1;
 		engine.run();
-		return 0;
 	}
-	else
-		return 1;
+	return 0;
 }
 
 int Glob2::runHostServer()
 {
 	if (verbose)
-		printf("Glob2::runHostServer():connecting to YOG as %s\n", globalContainer->getUsername());
+		std::cout << "Glob2::runHostServer():connecting to YOG as %s" << globalContainer->getUsername() << std::endl;
 	yog->enableConnection(globalContainer->hostServerUserName, globalContainer->hostServerPassWord, false);
 	
 	while(yog->yogGlobalState==YOG::YGS_CONNECTING)
