@@ -65,7 +65,7 @@ public:
 	Sint32 wDec, hDec;
 	
 	Sint32 waterRatio, sandRatio, grassRatio, desertRatio, wheatRatio,
-		woodRatio, algaeRatio, stoneRatio, riverDiameter, craterDensity, extraIslands;
+		woodRatio, fruitRatio, algaeRatio, stoneRatio, riverDiameter, craterDensity, extraIslands;
 	Sint32 oldIslandSize, oldBeach;
 	Sint32 smooth;
 	Sint32 ressource[MAX_NB_RESSOURCES];
@@ -78,7 +78,7 @@ public:
 	Sint32 bootX[32];
 	Sint32 bootY[32];
 public:
-	enum {DATA_SIZE=84+MAX_NB_RESSOURCES*4};
+	enum {DATA_SIZE=96+MAX_NB_RESSOURCES*4};
 protected:
 	//! Serialized form of MapGenerationDescriptor
 	Uint8 data[DATA_SIZE];
