@@ -20,6 +20,8 @@
 #include "MultiplayersConnectedScreen.h"
 #include "MultiplayersJoin.h"
 #include "Order.h"
+
+#include <FormatableString.h>
 #include <GraphicContext.h>
 #include <Toolkit.h>
 #include <StringTable.h>
@@ -144,10 +146,10 @@ void MultiplayersConnectedScreen::onTimer(Uint32 tick)
 		}
 		if ((multiplayersJoin->waitingState>=MultiplayersJoin::WS_SERVER_START_GAME))
 		{
-			char s[128];
-			snprintf(s, 128, "%s%d", Toolkit::getStringTable()->getString("[STARTING GAME ...]"), multiplayersJoin->startGameTimeCounter/20);
+			std::string s;
+			s = FormatableString("%0%1").arg(Toolkit::getStringTable()->getString("[STARTING GAME ...]")).arg(multiplayersJoin->startGameTimeCounter/20);
 			if (verbose)
-				printf("s=%s.\n", s);
+				printf("s=%s.\n", s.c_str());
 			startTimer->setText(s);
 		}
 	}
@@ -156,14 +158,14 @@ void MultiplayersConnectedScreen::onTimer(Uint32 tick)
 	if (lastProgress!=progress)
 	{
 		lastProgress=progress;
-		char s[128];
+		std::string s;
 		if (isFileMapDownload)
 		{
 			int percent=(int)(100.0*progress);
-			snprintf(s, 128, "%s%d%s", Toolkit::getStringTable()->getString("[downloaded at]"), percent, Toolkit::getStringTable()->getString("[percent]"));
+			s = FormatableString("%0%1%2").arg(Toolkit::getStringTable()->getString("[downloaded at]")).arg(percent).arg(Toolkit::getStringTable()->getString("[percent]"));
 		}
 		else
-			snprintf(s, 128, "%s", Toolkit::getStringTable()->getString("[download finished]"));
+			s = Toolkit::getStringTable()->getString("[download finished]");
 		startTimer->setText(s);
 	}
 
@@ -302,7 +304,7 @@ void MultiplayersConnectedScreen::onAction(Widget *source, Action action, int pa
 	else if (action==TEXT_VALIDATED)
 	{
 		assert(multiplayersJoin);
-		multiplayersJoin->sendMessage(textInput->getText());
+		multiplayersJoin->sendMessage(textInput->getText().c_str());
 		textInput->setText("");
 	}
 }
