@@ -26,6 +26,8 @@
 #include "MultiplayersJoin.h"
 #include "NetConsts.h"
 #include "Order.h"
+
+#include <FormatableString.h>
 #include <GUIText.h>
 #include <GUITextArea.h>
 #include <GUITextInput.h>
@@ -126,16 +128,16 @@ void MultiplayersHostScreen::onTimer(Uint32 tick)
 			int teamNumber=multiplayersHost->sessionInfo.players[i].teamNumber;
 			char playerName[32];
 			strncpy(playerName, multiplayersHost->sessionInfo.players[i].name, 32);
-			char shownInfo[128];
+			std::string shownInfo;
 			if (multiplayersHost->playerFileTra[i].wantsFile && !multiplayersHost->playerFileTra[i].receivedFile)
 			{
 				int percent=(100*multiplayersHost->playerFileTra[i].unreceivedIndex)/multiplayersHost->fileSize;
-				snprintf(shownInfo, 128, "%s (%d)", playerName, percent);
+				shownInfo = FormatableString("%0 (%1)").arg(playerName).arg(percent);
 			}
 			else
-				strncpy(shownInfo, playerName, 128);
+				shownInfo = playerName;
 
-			if (strncmp(shownInfo, text[i]->getText(), 128))
+			if (shownInfo != text[i]->getText())
 			{
 				text[i]->setText(shownInfo);
 				color[i]->setSelectedColor(teamNumber);
@@ -167,9 +169,9 @@ void MultiplayersHostScreen::onTimer(Uint32 tick)
 	{
 		multiplayersJoin=new MultiplayersJoin(shareOnYOG);
 		assert(BasePlayer::MAX_NAME_LENGTH==32);
-		strncpy(multiplayersJoin->playerName, globalContainer->getUsername(), 32);
+		strncpy(multiplayersJoin->playerName, globalContainer->getUsername().c_str(), 32);
 		multiplayersJoin->playerName[31]=0;
-		strncpy(multiplayersJoin->serverNickName, globalContainer->getUsername(), 32);
+		strncpy(multiplayersJoin->serverNickName, globalContainer->getUsername().c_str(), 32);
 		multiplayersJoin->serverNickName[31]=0;
 		strncpy(multiplayersJoin->serverName, globalContainer->getComputerHostName(), 256);
 		multiplayersJoin->serverName[255]=0;
@@ -184,9 +186,9 @@ void MultiplayersHostScreen::onTimer(Uint32 tick)
 
 	if (((timeCounter++ % 10)==0)&&(multiplayersHost->hostGlobalState>=MultiplayersHost::HGS_PLAYING_COUNTER))
 	{
-		char s[128];
-		snprintf(s, sizeof(s), "%s%d", Toolkit::getStringTable()->getString("[STARTING GAME ...]"), multiplayersHost->startGameTimeCounter/20);
-		printf("s=%s.\n", s);
+		std::string s;
+		s = FormatableString("%0%1").arg(Toolkit::getStringTable()->getString("[STARTING GAME ...]")).arg((multiplayersHost->startGameTimeCounter/20));
+		printf("s=%s.\n", s.c_str());
 		startTimer->setText(s);
 	}
 
@@ -387,10 +389,10 @@ void MultiplayersHostScreen::onAction(Widget *source, Action action, int par1, i
 	}
 	else if (action==TEXT_VALIDATED)
 	{
-		multiplayersHost->sendMessage(textInput->getText());
+		multiplayersHost->sendMessage(textInput->getText().c_str());
 		if (ircPtr)
 		{
-			const char *message = textInput->getText();
+			const char *message = textInput->getText().c_str();
 			if ((message[0] == '/') && (message[1]=='/'))
 				ircPtr->sendCommand(&message[1]);
 		}
