@@ -196,7 +196,7 @@ void MultiplayersJoin::dataPresenceRecieved(Uint8 *data, int size, IPaddress ip)
 	
 	if (serverNetProtocolVersion!=NET_PROTOCOL_VERSION || serverConfigCheckSum!=globalContainer->getConfigCheckSum())
 	{
-		fprintf(logFile, " bad serverNetProtocolVersion!=%d or serverNetProtocolVersion!=%08x\n",
+		fprintf(logFile, " bad serverNetProtocolVersion!=%d or serverConfigCheckSum!=%08x\n",
 				NET_PROTOCOL_VERSION, globalContainer->getConfigCheckSum());
 		if (shareOnYog)
 		{
@@ -303,12 +303,7 @@ void MultiplayersJoin::dataSessionInfoRecieved(Uint8 *data, int size, IPaddress
 	waitingTOTL=DEFAULT_NETWORK_TOTL;
 	
 	//do we need to download the file from host ? :
-	if (sessionInfo.mapGenerationDescriptor && sessionInfo.fileIsAMap)
-	{
-		fprintf(logFile, " no need for download, we have a random map.\n");
-		closeDownload();
-	}
-	else if (downloadStream && (filename == sessionInfo.getFileName()))
+	if (downloadStream && (filename == sessionInfo.getFileName()))
 	{
 		fprintf(logFile, " we are already downloading the map.\n");
 		fprintf(logFileDownload, " we are already downloading the map.\n");
@@ -1835,7 +1830,7 @@ bool MultiplayersJoin::tryConnection(YOG::GameInfo *yogGameInfo)
 		printf("tryConnection::serverName=%s\n", serverName);
 	//TODO: is the serverName string usefull ? If it is, the port needs to be passed too !
 	
-	strncpy(playerName, globalContainer->getUsername(), 32);
+	strncpy(playerName, globalContainer->getUsername().c_str(), 32);
 	playerName[31]=0;
 	strncpy(serverNickName, yogGameInfo->userName, 32);
 	serverNickName[31]=0;
