@@ -68,15 +68,16 @@ private:
 	List *methodes, *terrains;
 	Ratio *waterRatio, *sandRatio, *grassRatio, *desertRatio;
 	Ratio *wheatRatio, *woodRatio, *stoneRatio, *algaeRatio, *craterDensity;
-	Ratio *riverDiameter;
+	Ratio *riverDiameter, *fruitRatio;
 	Number *smooth, *extraIslands;
 	Number *nbTeams;
 	Ratio *oldIslandSize;
 	Number *oldBeach;
 	Number *nbWorkers;
 	Text *numberOfTeamText, *numberOfWorkerText, *craterDensityText, *extraIslandsText;
-	Text *ratioText, *waterText, *sandText, *grassText, *desertText, *wheatText, *woodText, *stoneText, *algaeText, *smoothingText, *riverDiameterText;
+	Text *ratioText, *waterText, *sandText, *grassText, *desertText, *wheatText, *woodText, *stoneText, *algaeText, *fruitText, *smoothingText, *riverDiameterText;
 	Text *oldIslandSizeText, *oldBeachSizeText;
+	
 
 public:
 	//! Constructor
