@@ -258,17 +258,17 @@ protected:
 	Uint8 *data;
 };
 
-class OrderModifyWarFlag:public OrderModify
+class OrderModifyMinLevelToFlag:public OrderModify
 {
 public:
-	OrderModifyWarFlag(const Uint8 *data, int dataLength);
-	OrderModifyWarFlag(Uint16 gid, Uint16 minLevelToFlag);
-	virtual ~OrderModifyWarFlag(void);
+	OrderModifyMinLevelToFlag(const Uint8 *data, int dataLength);
+	OrderModifyMinLevelToFlag(Uint16 gid, Uint16 minLevelToFlag);
+	virtual ~OrderModifyMinLevelToFlag(void);
 
 	Uint8 *getData(void);
 	bool setData(const Uint8 *data, int dataLength);
 	int getDataLength(void) { return 4; }
-	Uint8 getOrderType(void) { return ORDER_MODIFY_WAR_FLAG; }
+	Uint8 getOrderType(void) { return ORDER_MODIFY_MIN_LEVEL_TO_FLAG; }
 
 	Uint16 gid;
 	Uint16 minLevelToFlag;
