@@ -398,6 +398,21 @@ bool BasePlayer::send(const Uint8 u, const Uint8 v)
 	return send(data, 8);
 }
 
+bool BasePlayer::send(const Uint8 u, const Uint8 v, const Uint32 checksum)
+{
+	Uint8 data[12];
+	data[0]=u;
+	data[1]=0;
+	data[2]=0;
+	data[3]=0;
+	data[4]=v;
+	data[5]=0;
+	data[6]=0;
+	data[7]=0;
+	*((Uint32 *)(data+8))=SDL_SwapBE32(checksum);
+	return send(data, 12);
+}
+
 Player::Player()
 :BasePlayer()
 {
@@ -583,20 +598,20 @@ void Player::save(GAGCore::OutputStream  *stream)
 	stream->writeLeaveSection();
 }
 
-Uint32 Player::checkSum(std::list<Uint32> *checkSumsList)
+Uint32 Player::checkSum(std::vector<Uint32> *checkSumsVector)
 {
 	Uint32 cs;
 	if (ai)
 		cs=ai->step;
 	else
 		cs=0;
-	if (checkSumsList)
-		checkSumsList->push_back(cs);// [2+t*20+p*2]
+	if (checkSumsVector)
+		checkSumsVector->push_back(cs);// [2+t*20+p*2]
 	
 	cs^=BasePlayer::checkSum();
 	
-	if (checkSumsList)
-		checkSumsList->push_back(cs);// [3+t*20+p*2]
+	if (checkSumsVector)
+		checkSumsVector->push_back(cs);// [3+t*20+p*2]
 	
 	return cs;
 }
