@@ -25,7 +25,6 @@
 
 #include <iostream>
 #include <string>
-#include <deque>
 #include <vector>
 #include <algorithm>
 #include <string.h>
@@ -58,6 +57,7 @@ Token::TokenSymbolLookupTable Token::table[] =
 	{ S_NOT, "not" },
 
 	{ S_WAIT, "wait" },
+	{ S_SPACE, "space" },
 	{ S_TIMER, "timer" },
 	{ S_SHOW, "show" },
 	{ S_HIDE, "hide" },
@@ -145,6 +145,7 @@ Story::Story(Mapscript *mapscript)
 {
 	lineSelector = 0;
 	internTimer=0;
+	recievedSpace=false;
 	this->mapscript=mapscript;
 }
 
@@ -181,6 +182,8 @@ int Story::valueOfVariable(const Game *game, Token::TokenType type, int teamNumb
 			return latestStat->numberBuildingPerTypePerLevel[6][level];
 		case(Token::S_DEFENCE_B):
 			return latestStat->numberBuildingPerTypePerLevel[7][level];
+		case(Token::S_WALL_B):
+			return latestStat->numberBuildingPerTypePerLevel[11][level];
 		default:
 			assert(false);
 			return 0;
@@ -497,6 +500,19 @@ bool Story::testCondition(GameGUI *gui)
 				return true;
 			}
 
+			case (Token::S_SPACE):
+			{
+				if (recievedSpace)
+				{
+					return true;
+				}
+				else
+				{
+					gui->setSwallowSpaceKey(true);
+					return false;
+				}
+			}
+
 			case (Token::S_WAIT):
 			{
 				bool negate = false;
@@ -634,6 +650,7 @@ void Story::syncStep(GameGUI *gui)
 		cycleLeft--;
 		if (verbose)
 			std::cout << "Story::syncStep : SGSL thread " << this << " PC : " << lineSelector << " (" << Token::getNameByType(line[lineSelector].type) << ")" << std::endl;
+		recievedSpace=false;
 	}
 
 	if (!cycleLeft)
@@ -896,18 +913,148 @@ Mapscript::~Mapscript(void)
 	
 }
 
-bool Mapscript::load(GAGCore::InputStream *stream)
+bool Mapscript::load(GAGCore::InputStream *stream, Game *game)
 {
+	int versionMinor = game->session.versionMinor;
+	
 	stream->readEnterSection("SGSL");
+	
+	// load source code
 	sourceCode = stream->readText("sourceCode");
+	
+	// compile source code
+	ErrorReport er = compileScript(game);
+	if (er.type != ErrorReport::ET_OK)
+	{
+		printf("SGSL : %s at line %d on col %d\n", er.getErrorString(), er.line+1, er.col);
+		stream->readLeaveSection();
+		return false;
+	}
+	
+	// load state
+	if (versionMinor > 47)
+	{
+		// load main timer
+		mainTimer = stream->readSint32("mainTimer");
+		
+		// load hasWon / hasLost vectors
+		stream->readEnterSection("victoryConditions");
+		for (unsigned i = 0; i < (unsigned)game->session.numberOfTeam; i++)
+		{
+			stream->readEnterSection(i);
+			hasWon[i] = stream->readSint32("hasWon") != 0;
+			hasLost[i] = stream->readSint32("hasLost") != 0;
+			stream->readLeaveSection();
+		}
+		stream->readLeaveSection();
+		
+		// load stories datas
+		stream->readEnterSection("stories");
+		for (unsigned i = 0; i < stories.size(); i++)
+		{
+			stream->readEnterSection(i);
+			stories[i].lineSelector = stream->readSint32("ProgramCounter");
+			stories[i].internTimer = stream->readSint32("internTimer");
+			stream->readLeaveSection();
+		}
+		stream->readLeaveSection();
+		
+		// load areas
+		stream->readEnterSection("areas");
+		unsigned areasCount = stream->readUint32("areasCount");
+		for (unsigned i = 0; i < areasCount; i++)
+		{
+			stream->readEnterSection(i);
+			std::string name = stream->readText("name");
+			areas[name].x = stream->readSint32("x");
+			areas[name].y = stream->readSint32("y");
+			areas[name].r = stream->readSint32("r");
+			stream->readLeaveSection();
+		}
+		stream->readLeaveSection();
+		
+		// load flags
+		stream->readEnterSection("flags");
+		unsigned flagsCount = stream->readUint32("flagsCount");
+		for (unsigned i = 0; i < flagsCount; i++)
+		{
+			stream->readEnterSection(i);
+			std::string name = stream->readText("name");
+			Uint16 gbid = stream->readUint16("gbid");
+			Building *b = game->teams[Building::GIDtoTeam(gbid)]->myBuildings[Building::GIDtoID(gbid)];
+			assert(b);
+			flags[name] = b;
+			stream->readLeaveSection();
+		}
+		stream->readLeaveSection();
+	}
 	stream->readLeaveSection();
 	return true;
 }
 
-void Mapscript::save(GAGCore::OutputStream *stream)
+void Mapscript::save(GAGCore::OutputStream *stream, const Game *game)
 {
 	stream->writeEnterSection("SGSL");
+	
 	stream->writeText(sourceCode, "sourceCode");
+	
+	// save state
+	
+	// save main timer
+	stream->writeSint32(mainTimer, "mainTimer");
+	
+	// save hasWon / hasLost vectors
+	stream->writeEnterSection("victoryConditions");
+	for (unsigned i = 0; i < (unsigned)game->session.numberOfTeam; i++)
+	{
+		stream->writeEnterSection(i);
+		stream->writeSint32(hasWon[i] ? 1 : 0, "hasWon");
+		stream->writeSint32(hasLost[i] ? 1 : 0, "hasLost");
+		stream->writeLeaveSection();
+	}
+	stream->writeLeaveSection();
+	
+	// save stories datas
+	stream->writeEnterSection("stories");
+	for (unsigned i = 0; i < stories.size(); i++)
+	{
+		stream->writeEnterSection(i);
+		stream->writeSint32(stories[i].lineSelector, "ProgramCounter");
+		stream->writeSint32(stories[i].internTimer, "internTimer");
+		stream->writeLeaveSection();
+	}
+	stream->writeLeaveSection();
+	
+	// save areas
+	stream->writeEnterSection("areas");
+	stream->writeUint32(areas.size(), "areasCount");
+	unsigned i = 0;
+	for (AreaMap::iterator it = areas.begin(); it != areas.end(); ++it)
+	{
+		stream->writeEnterSection(i);
+		stream->writeText(it->first, "name");
+		stream->writeSint32(it->second.x, "x");
+		stream->writeSint32(it->second.y, "y");
+		stream->writeSint32(it->second.r, "r");
+		stream->writeLeaveSection();
+		i++;
+	}
+	stream->writeLeaveSection();
+	
+	// save flags
+	stream->writeEnterSection("flags");
+	stream->writeUint32(flags.size(), "flagsCount");
+	i = 0;
+	for (BuildingMap::iterator it = flags.begin(); it != flags.end(); ++it)
+	{
+		stream->writeEnterSection(i);
+		stream->writeText(it->first, "name");
+		stream->writeUint16(it->second->gid, "x");
+		stream->writeLeaveSection();
+		i++;
+	}
+	stream->writeLeaveSection();
+	
 	stream->writeLeaveSection();
 }
 
@@ -929,16 +1076,23 @@ void Mapscript::syncStep(GameGUI *gui)
 {
 	if (mainTimer)
 		mainTimer--;
-	for (std::deque<Story>::iterator it=stories.begin(); it!=stories.end(); ++it)
+	for (std::vector<Story>::iterator it=stories.begin(); it!=stories.end(); ++it)
 	{
+		if (gui->isSpaceSet())
+			it->sendSpace();
 		it->syncStep(gui);
 	}
+	if(gui->isSpaceSet())
+	{
+		gui->setIsSpaceSet(false);
+		gui->setSwallowSpaceKey(false);
+	}
 }
 
 Sint32 Mapscript::checkSum()
 {
 	Sint32 cs=0;
-	for (std::deque<Story>::iterator it=stories.begin(); it!=stories.end(); ++it)
+	for (std::vector<Story>::iterator it=stories.begin(); it!=stories.end(); ++it)
 	{
 		cs^=it->checkSum();
 		cs=(cs<<28)|(cs>>4);
@@ -1013,7 +1167,7 @@ ErrorReport Mapscript::parseScript(Aquisition *donnees, Game *game)
 		} \
 	}
 
-	// Cheks for right number of arguments
+	// Checks for right number of arguments
 	#define CHECK_ARGUMENT \
 	{ \
 		if (donnees->getToken()->type == Token::S_PARCLOSE || donnees->getToken()->type == Token::S_SEMICOL) \
@@ -1533,23 +1687,37 @@ ErrorReport Mapscript::parseScript(Aquisition *donnees, Game *game)
 						if (donnees->getToken()->type >= Token::S_SWARM_B)
 						{
 							// Buildings
-							// level
 							CHECK_PAROPEN;
 							NEXT_TOKEN;
 							CHECK_ARGUMENT;
+							// team
 							if (donnees->getToken()->type != Token::INT)
 							{
 								er.type=ErrorReport::ET_SYNTAX_ERROR;
 								break;
 							}
-							else if ((donnees->getToken()->value < 0) || (donnees->getToken()->value > 2))
+							else if (donnees->getToken()->value >= game->session.numberOfTeam)
 							{
-								er.type=ErrorReport::ET_INVALID_VALUE;
+								er.type=ErrorReport::ET_INVALID_TEAM;
 								break;
 							}
 							thisone.line.push_back(*donnees->getToken());
 							CHECK_SEMICOL;
 							NEXT_TOKEN;
+							CHECK_ARGUMENT;
+
+							// level
+							if (donnees->getToken()->type != Token::INT)
+							{
+								er.type=ErrorReport::ET_SYNTAX_ERROR;
+								break;
+							}
+							else if ((donnees->getToken()->value < 0) || (donnees->getToken()->value > 5))
+							{
+								er.type=ErrorReport::ET_INVALID_VALUE;
+								break;
+							}
+							thisone.line.push_back(*donnees->getToken());
 						}
 						else
 						{
@@ -1557,20 +1725,21 @@ ErrorReport Mapscript::parseScript(Aquisition *donnees, Game *game)
 							CHECK_PAROPEN;
 							NEXT_TOKEN;
 							CHECK_ARGUMENT;
+							// team
+							if (donnees->getToken()->type != Token::INT)
+							{
+								er.type=ErrorReport::ET_SYNTAX_ERROR;
+								break;
+							}
+							else if (donnees->getToken()->value >= game->session.numberOfTeam)
+							{
+								er.type=ErrorReport::ET_INVALID_TEAM;
+								break;
+							}
+							thisone.line.push_back(*donnees->getToken());
 						}
+						CHECK_PARCLOSE;
 
-						// team
-						if (donnees->getToken()->type != Token::INT)
-						{
-							er.type=ErrorReport::ET_SYNTAX_ERROR;
-							break;
-						}
-						else if (donnees->getToken()->value >= game->session.numberOfTeam)
-						{
-							er.type=ErrorReport::ET_INVALID_TEAM;
-							break;
-						}
-						thisone.line.push_back(*donnees->getToken());
 						/*NEXT_TOKEN;
 						//Optional "areaName"
 						if (donnees->getToken()->type != Token::S_PARCLOSE)
@@ -1593,7 +1762,6 @@ ErrorReport Mapscript::parseScript(Aquisition *donnees, Game *game)
 						else
 						{ // there was no flag name but a closing parenthesis
 						}*/
-						CHECK_PARCLOSE;
 
 						NEXT_TOKEN;
 						CHECK_ARGUMENT;
@@ -1708,6 +1876,13 @@ ErrorReport Mapscript::parseScript(Aquisition *donnees, Game *game)
 				}
 				break;
 
+				case (Token::S_SPACE):
+				{
+					thisone.line.push_back(*donnees->getToken());
+					NEXT_TOKEN;
+				}
+				break;
+
 				case (Token::S_EOF):
 				{
 				}
