@@ -27,7 +27,6 @@
 #define SGSL_H
 
 #include <string>
-#include <deque>
 #include <vector>
 #include <map>
 #include <stdio.h>
@@ -65,6 +64,7 @@ struct Token
 
 		// Functions
 		S_WAIT=50,
+		S_SPACE,
 		S_TIMER,
 		S_SHOW,
 		S_HIDE,
@@ -238,19 +238,22 @@ public:
 	virtual ~Story();
 
 public:
-	std::deque<Token> line;
+	std::vector<Token> line;
 	std::map<std::string, int> labels;
+	int lineSelector; //!< PC : Program Counter
+	int internTimer;
 
 	void syncStep(GameGUI *gui);
 	Sint32 checkSum() { return lineSelector; }
 
+	void sendSpace() { recievedSpace=true; }
 private:
 	bool conditionTester(const Game *game, int pc, bool l);
 	bool testCondition(GameGUI *gui);
 	int valueOfVariable(const Game *game, Token::TokenType type, int teamNumber, int level);
-	int lineSelector;
+	
 	Mapscript *mapscript;
-	int internTimer;
+	bool recievedSpace;
 };
 
 struct Area
@@ -275,9 +278,9 @@ public:
 	ErrorReport loadScript(const char *filename, Game *game);
 
 	//! Load a script, read source code
-	bool load(GAGCore::InputStream *stream);
+	bool load(GAGCore::InputStream *stream, Game *game);
 	//! Save a script, write source code
-	void save(GAGCore::OutputStream *stream);
+	void save(GAGCore::OutputStream *stream, const Game *game);
 
 	void syncStep(GameGUI *gui);
 	Sint32 checkSum();
@@ -301,7 +304,7 @@ private:
 	int mainTimer;
 	std::vector<bool> hasWon, hasLost;
 
-	std::deque<Story> stories;
+	std::vector<Story> stories;
 
 	AreaMap areas;
 
