@@ -23,6 +23,8 @@
 #include "Game.h"
 #include "GameGUILoadSave.h"
 #include "Utilities.h"
+
+#include <FormatableString.h>
 #include <Toolkit.h>
 #include <StringTable.h>
 #include <SupportFunctions.h>
@@ -35,7 +37,7 @@ using namespace GAGGUI;
 
 #include <algorithm>
 
-//! Main menu screen
+
 ScriptEditorScreen::ScriptEditorScreen(Mapscript *mapScript, Game *game)
 :OverlayScreen(globalContainer->gfx, 600, 400)
 {
@@ -66,6 +68,8 @@ ScriptEditorScreen::ScriptEditorScreen(Mapscript *mapScript, Game *game)
 	addWidget(new TextButton(230, 10, 100, 20, ALIGN_LEFT, ALIGN_LEFT, "", -1, -1, "standard", "Campaign text", TAB_CAMPAIGN_TEXT));
 	mode = new Text(20, 10, ALIGN_RIGHT, ALIGN_TOP, "standard", "Script");
 	addWidget(mode);
+	
+	// important, widgets must be initialised by hand as we use custom event loop
 	dispatchInit();
 }
 
@@ -83,7 +87,7 @@ bool ScriptEditorScreen::testCompile(void)
 	else
 	{
 		compilationResult->setStyle(Font::Style(Font::STYLE_NORMAL, 255, 50, 50));
-		compilationResult->setText(GAGCore::nsprintf("Compilation failure : %d:%d:(%d):%s", er.line+1, er.col, er.pos, er.getErrorString()).c_str());
+		compilationResult->setText(FormatableString("Compilation failure : %0:%1:(%2):%3").arg(er.line+1).arg(er.col).arg(er.pos).arg(er.getErrorString()).c_str());
 		scriptEditor->setCursorPos(er.pos);
 		return false;
 	}
@@ -207,7 +211,7 @@ void ScriptEditorScreen::loadSave(bool isLoad, const char *dir, const char *ext)
 				if (!scriptEditor->load(loadSaveScreen->getFileName()))
 				{
 					compilationResult->setStyle(Font::Style(Font::STYLE_NORMAL, 255, 50, 50));
-					compilationResult->setText(GAGCore::nsprintf("Loading script from %s failed", loadSaveScreen->getName()).c_str());
+					compilationResult->setText(FormatableString("Loading script from %0 failed").arg(loadSaveScreen->getName()).c_str());
 				}
 			}
 			else
@@ -215,7 +219,7 @@ void ScriptEditorScreen::loadSave(bool isLoad, const char *dir, const char *ext)
 				if (!scriptEditor->save(loadSaveScreen->getFileName()))
 				{
 					compilationResult->setStyle(Font::Style(Font::STYLE_NORMAL, 255, 50, 50));
-					compilationResult->setText(GAGCore::nsprintf("Saving script to %s failed", loadSaveScreen->getName()).c_str());
+					compilationResult->setText(FormatableString("Saving script to %0 failed").arg(loadSaveScreen->getName()).c_str());
 				}
 			}
 		}
@@ -226,7 +230,7 @@ void ScriptEditorScreen::loadSave(bool isLoad, const char *dir, const char *ext)
 				if (!campaignTextEditor->load(loadSaveScreen->getFileName()))
 				{
 					compilationResult->setStyle(Font::Style(Font::STYLE_NORMAL, 255, 50, 50));
-					compilationResult->setText(GAGCore::nsprintf("Loading campaign text from %s failed", loadSaveScreen->getName()).c_str());
+					compilationResult->setText(FormatableString("Loading campaign text from %0 failed").arg(loadSaveScreen->getName()).c_str());
 				}
 			}
 			else
@@ -234,7 +238,7 @@ void ScriptEditorScreen::loadSave(bool isLoad, const char *dir, const char *ext)
 				if (!campaignTextEditor->save(loadSaveScreen->getFileName()))
 				{
 					compilationResult->setStyle(Font::Style(Font::STYLE_NORMAL, 255, 50, 50));
-					compilationResult->setText(GAGCore::nsprintf("Saving campaign text to %s failed", loadSaveScreen->getName()).c_str());
+					compilationResult->setText(FormatableString("Saving campaign text to %0 failed").arg(loadSaveScreen->getName()).c_str());
 				}
 			}
 		}
