@@ -21,16 +21,19 @@
 #define __SECTOR_H
 
 #include <list>
-#ifndef DX9_BACKEND	// TODO:Die!
-#include <SDL_rwops.h>
-#else
-#include <Types.h>
-#endif
 
 class Map;
 class Game;
 class Bullet;
 class Explosion;
+class Team;
+
+struct UnitDeathAnimation
+{
+	UnitDeathAnimation(int x, int y, Team *team);
+	int x, y, ticksLeft;
+	Team *team;
+};
 
 // a 16x16 piece of Map
 class Sector
@@ -46,9 +49,10 @@ public:
 
 	std::list<Bullet *> bullets;
 	std::list<BulletExplosion *> explosions;
+	std::list<UnitDeathAnimation *> deathAnimations;
 
 	void save(GAGCore::OutputStream *stream);
-	bool load(GAGCore::InputStream *stream, Game *game);
+	bool load(GAGCore::InputStream *stream, Game *game, Sint32 versionMinor);
 
 	void step(void);
 private:
