@@ -25,6 +25,8 @@
 #include "Utilities.h"
 #include "Game.h"
 #include "GlobalContainer.h"
+
+#include <FormatableString.h>
 #include <Toolkit.h>
 #include <StringTable.h>
 #include <Stream.h>
@@ -214,15 +216,15 @@ void SessionInfo::draw(DrawableSurface *gfx)
 	}
 }
 */
-void SessionInfo::getPlayerInfo(int playerNumber, int *teamNumber, char *infoString, SessionInfo *savedSessionInfo, int stringLen)
+void SessionInfo::getPlayerInfo(int playerNumber, int *teamNumber, std::string &infoString, SessionInfo *savedSessionInfo)
 {
 	assert(playerNumber>=0);
 	assert(playerNumber<numberOfPlayer);
 	*teamNumber=players[playerNumber].teamNumber;
 	if (players[playerNumber].type==BasePlayer::P_IP)
-		snprintf(infoString, stringLen, "%s : %s", players[playerNumber].name, Utilities::stringIP(players[playerNumber].ip));
+		infoString = FormatableString("%0 : %1").arg(players[playerNumber].name).arg(Utilities::stringIP(players[playerNumber].ip));
 	else if (players[playerNumber].type>=BasePlayer::P_AI)
-		snprintf(infoString, stringLen, "%s : (%s)", players[playerNumber].name, Toolkit::getStringTable()->getString("[AI]", players[playerNumber].type-BasePlayer::P_AI));
+		infoString = FormatableString("%0 : (%1)").arg(players[playerNumber].name).arg(Toolkit::getStringTable()->getString("[AI]", players[playerNumber].type-BasePlayer::P_AI));
 	else
 		assert(false);
 }
