@@ -21,6 +21,7 @@
 #define __SETTINGSSCREEN_H
 
 #include "Glob2Screen.h"
+#include "Settings.h"
 #include <string>
 
 namespace GAGGUI
@@ -31,6 +32,7 @@ namespace GAGGUI
 	class OnOffButton;
 	class Text;
 	class Selector;
+	class Number;
 }
 
 class SettingsScreen : public Glob2Screen
@@ -45,22 +47,44 @@ public:
 		LOWQUALITY = 5,
 		CUSTOMCUR = 6,
 		MUTE = 7,
+		REMEMBERUNIT = 8,
+		GENERALSETTINGS = 9,
+		UNITSETTINGS = 10,
+		KEYBOARDSETTINGS = 11,
+		RESTOREDEFAULTSHORTCUTS=12,
+		GAMESHORTCUTS=13,
+		EDITORSHORTCUTS=14,
 	};
 private:
+	Settings old_settings;
 	List *languageList;
 	List *modeList;
 	TextInput *userName;
-	int oldLanguage, oldScreenW, oldScreenH, oldScreenFlags, oldGraphicType, oldOptionFlags, oldMusicVol, oldMute;
 	
-	TextButton *ok, *cancel;
+	TextButton *ok, *cancel, *generalsettings, *unitsettings, *keyboardsettings;
 	OnOffButton *fullscreen, *usegpu, *lowquality, *customcur;
 	Selector *musicVol;
-	OnOffButton *audioMute;
-	Text *title, *language, *display, *usernameText, *audio;
-	Text *fullscreenText, *usegpuText, *lowqualityText, *customcurText, *musicVolText, *audioMuteText;
+	OnOffButton *audioMute, *rememberUnitButton;
+	Number *warflagUnitRatio, *clearflagUnitRatio, *exploreflagUnitRatio;
+//	Text *title;
+	Text *language, *display, *usernameText, *audio;
+	Text *fullscreenText, *usegpuText, *lowqualityText, *customcurText, *musicVolText, *audioMuteText, *warflagUnitText, *clearflagUnitText, *exploreflagUnitText, *rememberUnitText;
 	Text *actDisplay;
 	Text *rebootWarning;
 
+	TextButton* game_shortcuts;
+	TextButton* editor_shortcuts;
+	List* keyboard_shortcut_names;
+	std::vector<std::string> internal_names;
+	List* keyboard_shortcuts;
+	std::vector<std::string> shortcut_actions;
+	std::vector<std::string> shortcut_names;
+	List* editor_keyboard_shortcuts;
+	std::vector<std::string> editor_shortcut_actions;
+	std::vector<std::string> editor_shortcut_names;
+	TextButton* restore_default_shortcuts;
+	void reset_names();
+
 	bool gfxAltered;
 	
 	//! If GL is enabled, hide useless options
