@@ -9,12 +9,12 @@
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
 //#include <float.h>
@@ -1140,8 +1140,8 @@ Building *Team::findBestFillable(Unit *unit)
 	}
 
 	//printf(" allForeignSendRessourceMask=%d, allForeignReceiveRessourceMask=%d\n", allForeignSendRessourceMask, allForeignReceiveRessourceMask);
-	if (allForeignSendRessourceMask==0 || allForeignReceiveRessourceMask==0)
-		return NULL;
+//	if (allForeignSendRessourceMask==0 || allForeignReceiveRessourceMask==0)
+//		return NULL;
 
 	// We compute all what's available from our own ressources: (mask)
 	Uint32 allOwnSendRessourceMask=0;
@@ -1162,8 +1162,8 @@ Building *Team::findBestFillable(Unit *unit)
 	}
 
 	//printf(" allOwnSendRessourceMask=%d, allOwnReceiveRessourceMask=%d\n", allOwnSendRessourceMask, allOwnReceiveRessourceMask);
-	if ((allForeignSendRessourceMask & allOwnReceiveRessourceMask)==0 || (allForeignReceiveRessourceMask & allOwnSendRessourceMask)==0)
-		return NULL;
+//	if ((allForeignSendRessourceMask & allOwnReceiveRessourceMask)==0 || (allForeignReceiveRessourceMask & allOwnSendRessourceMask)==0)
+//		return NULL;
 
 	choosen=NULL;
 	bestScore=INT_MAX;
@@ -1188,25 +1188,25 @@ Building *Team::findBestFillable(Unit *unit)
 						Sint32 missingUnitsToWork=(*bi)->maxUnitWorking-(*bi)->unitsWorking.size();
 						int foreignBuildingDist;
 						if (missingUnitsToWork
-					&& (sendRessourceMask & foreignReceiveRessourceMask)
-					&& (receiveRessourceMask & foreignSendRessourceMask)
-					&& map->buildingAvailable(*fbi, canSwim, x, y, &foreignBuildingDist)
-					&& (buildingDist+foreignBuildingDist)<(timeLeft>>1))
-				{
-					Sint32 newScore=((buildingDist+foreignBuildingDist)<<8)/missingUnitsToWork;
-					if (newScore<bestScore)
-					{
-						choosen=*bi;
-						bestScore=newScore;
-						assert(choosen);
-						unit->ownExchangeBuilding=*bi;
-						unit->foreingExchangeBuilding=*fbi;
-						unit->destinationPurprose=receiveRessourceMask & foreignSendRessourceMask;
-						fprintf(logFile, "[%d] tdp5 destinationPurprose=%d\n", unit->gid, unit->destinationPurprose);
+							&& (sendRessourceMask & foreignReceiveRessourceMask)
+							&& (receiveRessourceMask & foreignSendRessourceMask)
+							&& map->buildingAvailable(*fbi, canSwim, x, y, &foreignBuildingDist)
+							&& (buildingDist+foreignBuildingDist)<(timeLeft>>1))
+						{
+							Sint32 newScore=((buildingDist+foreignBuildingDist)<<8)/missingUnitsToWork;
+							if (newScore<bestScore)
+							{
+								choosen=*bi;
+								bestScore=newScore;
+								assert(choosen);
+								unit->ownExchangeBuilding=*bi;
+								unit->foreingExchangeBuilding=*fbi;
+								unit->destinationPurprose=receiveRessourceMask & foreignSendRessourceMask;
+								fprintf(logFile, "[%d] tdp5 destinationPurprose=%d\n", unit->gid, unit->destinationPurprose);
+							}
+						}
 					}
 				}
-			}
-		}
 	}
 
 	return choosen;
@@ -1518,10 +1518,10 @@ void Team::syncStep(void)
 
 	for (std::list<Building *>::iterator it=buildingsTryToBuildingSiteRoom.begin(); it!=buildingsTryToBuildingSiteRoom.end(); ++it)
 		if ((*it)->tryToBuildingSiteRoom())
-	{
-		std::list<Building *>::iterator ittemp=it;
-		it=buildingsTryToBuildingSiteRoom.erase(ittemp);
-	}
+		{
+			std::list<Building *>::iterator ittemp=it;
+			it=buildingsTryToBuildingSiteRoom.erase(ittemp);
+		}
 
 	//printf("subscribeForInside.size()=%d\n", subscribeForInside.size());
 	for (std::list<Building *>::iterator it=subscribeForInside.begin(); it!=subscribeForInside.end(); ++it)
@@ -1530,11 +1530,11 @@ void Team::syncStep(void)
 
 	for (std::list<Building *>::iterator it=subscribeForInside.begin(); it!=subscribeForInside.end(); ++it)
 		if ((*it)->unitsInsideSubscribe.empty())
-	{
-		(*it)->subscribeForInside=2;
-		std::list<Building *>::iterator ittemp=it;
-		it=subscribeForInside.erase(ittemp);
-	}
+		{
+			(*it)->subscribeForInside=2;
+			std::list<Building *>::iterator ittemp=it;
+			it=subscribeForInside.erase(ittemp);
+		}
 
 	//subscribeToBringRessourcesStep
 	for (std::list<Building *>::iterator it=subscribeToBringRessources.begin(); it!=subscribeToBringRessources.end(); ++it)
@@ -1543,11 +1543,11 @@ void Team::syncStep(void)
 
 	for (std::list<Building *>::iterator it=subscribeToBringRessources.begin(); it!=subscribeToBringRessources.end(); ++it)
 		if ((Sint32)(*it)->unitsWorking.size()>=(*it)->maxUnitWorking)
-	{
-		(*it)->subscribeToBringRessources=2;
-		std::list<Building *>::iterator ittemp=it;
-		it=subscribeToBringRessources.erase(ittemp);
-	}
+		{
+			(*it)->subscribeToBringRessources=2;
+			std::list<Building *>::iterator ittemp=it;
+			it=subscribeToBringRessources.erase(ittemp);
+		}
 
 	//subscribeForFlagingStep
 	for (std::list<Building *>::iterator it=subscribeForFlaging.begin(); it!=subscribeForFlaging.end(); ++it)
@@ -1556,20 +1556,27 @@ void Team::syncStep(void)
 
 	for (std::list<Building *>::iterator it=subscribeForFlaging.begin(); it!=subscribeForFlaging.end(); ++it)
 		if ((Sint32)(*it)->unitsWorking.size()>=(*it)->maxUnitWorking)
-	{
-		(*it)->subscribeForFlaging=2;
-		std::list<Building *>::iterator ittemp=it;
-		it=subscribeForFlaging.erase(ittemp);
-	}
+		{
+			(*it)->subscribeForFlaging=2;
+			std::list<Building *>::iterator ittemp=it;
+			it=subscribeForFlaging.erase(ittemp);
+		}
 
 	bool isEnoughFoodInSwarm=false;
 
-	for (std::list<Building *>::iterator it=swarms.begin(); it!=swarms.end(); ++it)
+	for (int i=0; i<1024; ++i)
 	{
-		if (!(*it)->locked[1] && (*it)->ressources[CORN]>(*it)->type->ressourceForOneUnit)
-			isEnoughFoodInSwarm=true;
-		(*it)->swarmStep();
+		if(myBuildings[i])
+			if(myBuildings[i]->type->useTeamRessources && game->stepCounter%20 == 0)
+				myBuildings[i]->updateCallLists();
 	}
+	
+	for (std::list<Building *>::iterator it=swarms.begin(); it!=swarms.end(); ++it)
+		{
+			if (!(*it)->locked[1] && (*it)->ressources[CORN]>(*it)->type->ressourceForOneUnit)
+				isEnoughFoodInSwarm=true;
+			(*it)->swarmStep();
+		}
 
 	for (std::list<Building *>::iterator it=turrets.begin(); it!=turrets.end(); ++it)
 		(*it)->turretStep();
@@ -1622,6 +1629,7 @@ void Team::checkControllingPlayers(void)
 
 void Team::dirtyGlobalGradient()
 {
+	game->dirtyWarFlagGradient();
 	for (int id=0; id<1024; id++)
 	{
 		Building *b=myBuildings[id];
@@ -1629,7 +1637,7 @@ void Team::dirtyGlobalGradient()
 			for (int canSwim=0; canSwim<2; canSwim++)
 				if (b->globalGradient[canSwim])
 				{
-			//printf("freeing globalGradient for gbid=%d (%p)\n", b->gid, b->globalGradient[canSwim]);
+					//printf("freeing globalGradient for gbid=%d (%p)\n", b->gid, b->globalGradient[canSwim]);
 					delete[] b->globalGradient[canSwim];
 					b->globalGradient[canSwim]=NULL;
 					b->locked[canSwim]=false;
@@ -1637,8 +1645,21 @@ void Team::dirtyGlobalGradient()
 	}
 }
 
-
-
+void Team::dirtyWarFlagGradient()
+{
+	for (std::list<Building *>::const_iterator it = virtualBuildings.begin(); it != virtualBuildings.end(); ++it)
+	{
+		Building *b = *it;
+		if (b->type->zonable[WARRIOR])
+			for (int canSwim=0; canSwim<2; canSwim++)
+				if (b->globalGradient[canSwim])
+				{
+					delete[] b->globalGradient[canSwim];
+					b->globalGradient[canSwim]=NULL;
+					b->locked[canSwim]=false;
+				}
+	}
+}
 
 Uint32 Team::checkSum(std::vector<Uint32> *checkSumsVector, std::vector<Uint32> *checkSumsVectorForBuildings, std::vector<Uint32> *checkSumsVectorForUnits)
 {
