@@ -19,6 +19,7 @@
 
 #include <sstream>
 
+#include <FormatableString.h>
 #include <GraphicContext.h>
 #include <Toolkit.h>
 #include <StringTable.h>
@@ -31,15 +32,26 @@
 #include "TeamStat.h"
 #include "Unit.h"
 
+
+EndOfGameStat::EndOfGameStat(int units, int buildings, int prestige, int hp, int attack, int defense)
+{
+	value[TYPE_UNITS]=units;
+	value[TYPE_BUILDINGS]=buildings;
+	value[TYPE_PRESTIGE]=prestige;
+	value[TYPE_HP]=hp;
+	value[TYPE_ATTACK]=attack;
+	value[TYPE_DEFENSE]=defense;
+}
+
+
+
 TeamStats::TeamStats()
 {
 	statsIndex=0;
 	smoothedIndex=0;
-	endOfGameStatIndex=0;
 	
 	memset(stats, 0, sizeof(TeamStat)*STATS_SIZE);
 	memset(smoothedStats, 0, sizeof(TeamSmoothedStat)*STATS_SMOOTH_SIZE);
-	memset(endOfGameStats, 0, sizeof(EndOfGameStat)*END_OF_GAME_STATS_SIZE);
 }
 
 TeamStats::~TeamStats()
@@ -52,16 +64,8 @@ void TeamStats::step(Team *team, bool reloaded)
 	// handle end of game stat step
 	if (((team->game->stepCounter & 0x1FF) == 0) && !reloaded)
 	{
-		// we copy stats to end of game stat
-		endOfGameStats[endOfGameStatIndex].value[EndOfGameStat::TYPE_UNITS] = stats[statsIndex].totalUnit;
-		endOfGameStats[endOfGameStatIndex].value[EndOfGameStat::TYPE_BUILDINGS] = stats[statsIndex].totalBuilding;
-		endOfGameStats[endOfGameStatIndex].value[EndOfGameStat::TYPE_PRESTIGE] = team->prestige;
-		endOfGameStats[endOfGameStatIndex].value[EndOfGameStat::TYPE_HP] = stats[statsIndex].totalHP;
-		endOfGameStats[endOfGameStatIndex].value[EndOfGameStat::TYPE_ATTACK] = stats[statsIndex].totalAttackPower;
-		endOfGameStats[endOfGameStatIndex].value[EndOfGameStat::TYPE_DEFENSE] = stats[statsIndex].totalDefensePower;
-
-		endOfGameStatIndex++;
-		endOfGameStatIndex%=END_OF_GAME_STATS_SIZE;
+		endOfGameStats.push_back(EndOfGameStat(stats[statsIndex].totalUnit, stats[statsIndex].totalBuilding, team->prestige,
+			stats[statsIndex].totalHP, stats[statsIndex].totalAttackPower, stats[statsIndex].totalDefensePower));
 	}
 	
 	// handle in game stat step
@@ -202,7 +206,7 @@ void TeamStats::drawText(int pos)
 	
 	// general
 	gfx->drawString(textStartPosX, textStartPosY, font, strings->getString("[Statistics]"));
-	gfx->drawString(textStartPosX, textStartPosY+15, font, GAGCore::nsprintf("%d %s", newStats.totalUnit, strings->getString("[Units]")).c_str());
+	gfx->drawString(textStartPosX, textStartPosY+15, font, FormatableString("%0 %1").arg(newStats.totalUnit).arg(strings->getString("[Units]")).c_str());
 	if (newStats.totalUnit)
 	{
 		// worker
@@ -213,30 +217,30 @@ void TeamStats::drawText(int pos)
 			free=0;
 			seeking=newStats.isFree[0];
 		}
-		gfx->drawString(textStartPosX, textStartPosY+30, font, GAGCore::nsprintf("%d %s (%.0f %%)", newStats.numberUnitPerType[0], strings->getString("[workers]"), ((float)newStats.numberUnitPerType[0])*100.0f/((float)newStats.totalUnit)).c_str());
-		gfx->drawString(textStartPosX+5, textStartPosY+42, font, GAGCore::nsprintf("%s %d %s", strings->getString("[of which]"), free, strings->getString("[free]")).c_str());
-		gfx->drawString(textStartPosX+5, textStartPosY+54, font, GAGCore::nsprintf("%s %d %s", strings->getString("[and]"), seeking, strings->getString("[seeking a job]")).c_str());
+		gfx->drawString(textStartPosX, textStartPosY+30, font, FormatableString("%0 %1 (%2 %)").arg(newStats.numberUnitPerType[0]).arg(strings->getString("[workers]")).arg(((float)newStats.numberUnitPerType[0])*100.0f/((float)newStats.totalUnit), 0, 0).c_str());
+		gfx->drawString(textStartPosX+5, textStartPosY+42, font, FormatableString("%0 %1 %2").arg(strings->getString("[of which]")).arg(free).arg(strings->getString("[free]")).c_str());
+		gfx->drawString(textStartPosX+5, textStartPosY+54, font, FormatableString("%0 %1 %2").arg(strings->getString("[and]")).arg(seeking).arg(strings->getString("[seeking a job]")).c_str());
 
 		// explorer
-		gfx->drawString(textStartPosX, textStartPosY+69, font, GAGCore::nsprintf("%d %s (%.0f %%)", newStats.numberUnitPerType[1], strings->getString("[explorers]"), ((float)newStats.numberUnitPerType[1])*100.0f/((float)newStats.totalUnit)).c_str());
-		gfx->drawString(textStartPosX+5, textStartPosY+81, font, GAGCore::nsprintf("%s %d %s", strings->getString("[of which]"), newStats.isFree[1], strings->getString("[free]")).c_str());
+		gfx->drawString(textStartPosX, textStartPosY+69, font, FormatableString("%0 %1 (%2 %)").arg(newStats.numberUnitPerType[1]).arg(strings->getString("[explorers]")).arg(((float)newStats.numberUnitPerType[1])*100.0f/((float)newStats.totalUnit), 0, 0).c_str());
+		gfx->drawString(textStartPosX+5, textStartPosY+81, font, FormatableString("%0 %1 %2").arg(strings->getString("[of which]")).arg(newStats.isFree[1]).arg(strings->getString("[free]")).c_str());
 		// warrior
-		gfx->drawString(textStartPosX, textStartPosY+96, font, GAGCore::nsprintf("%d %s (%.0f %%)", newStats.numberUnitPerType[2], strings->getString("[warriors]"), ((float)newStats.numberUnitPerType[2])*100.0f/((float)newStats.totalUnit)).c_str());
-		gfx->drawString(textStartPosX+5, textStartPosY+108, font, GAGCore::nsprintf("%s %d %s", strings->getString("[of which]"), newStats.isFree[2], strings->getString("[free]")).c_str());
+		gfx->drawString(textStartPosX, textStartPosY+96, font, FormatableString("%0 %1 (%2 %)").arg(newStats.numberUnitPerType[2]).arg(strings->getString("[warriors]")).arg(((float)newStats.numberUnitPerType[2])*100.0f/((float)newStats.totalUnit), 0, 0).c_str());
+		gfx->drawString(textStartPosX+5, textStartPosY+108, font, FormatableString("%0 %1 %2").arg(strings->getString("[of which]")).arg(newStats.isFree[2]).arg(strings->getString("[free]")).c_str());
 
 		// living state
-		gfx->drawString(textStartPosX, textStartPosY+123, font, GAGCore::nsprintf("%d %s (%.0f %%)", newStats.needNothing, strings->getString("[are ok]"), ((float)newStats.needNothing)*100.0f/((float)newStats.totalUnit)).c_str());
-		gfx->drawString(textStartPosX, textStartPosY+135, font, GAGCore::nsprintf("%d %s (%.0f %%)", newStats.needFood, strings->getString("[are hungry]"), ((float)newStats.needFood)*100.0f/((float)newStats.totalUnit)).c_str());
-		gfx->drawString(textStartPosX, textStartPosY+147, font, GAGCore::nsprintf("%d %s (%.0f %%)", newStats.needFoodCritical, strings->getString("[are dying hungry]"), ((float)newStats.needFoodCritical)*100.0f/((float)newStats.totalUnit)).c_str());
-		gfx->drawString(textStartPosX, textStartPosY+159, font, GAGCore::nsprintf("%d %s (%.0f %%)", newStats.needHeal, strings->getString("[are wonded]"), ((float)newStats.needHeal)*100.0f/((float)newStats.totalUnit)).c_str());
+		gfx->drawString(textStartPosX, textStartPosY+123, font, FormatableString("%0 %1 (%2 %)").arg(newStats.needNothing).arg(strings->getString("[are ok]")).arg(((float)newStats.needNothing)*100.0f/((float)newStats.totalUnit), 0, 0).c_str());
+		gfx->drawString(textStartPosX, textStartPosY+135, font, FormatableString("%0 %1 (%2 %)").arg(newStats.needFood).arg(strings->getString("[are hungry]")).arg(((float)newStats.needFood)*100.0f/((float)newStats.totalUnit), 0, 0).c_str());
+		gfx->drawString(textStartPosX, textStartPosY+147, font, FormatableString("%0 %1 (%2 %)").arg(newStats.needFoodCritical).arg(strings->getString("[are dying hungry]")).arg(((float)newStats.needFoodCritical)*100.0f/((float)newStats.totalUnit), 0, 0).c_str());
+		gfx->drawString(textStartPosX, textStartPosY+159, font, FormatableString("%0 %1 (%2 %)").arg(newStats.needHeal).arg(strings->getString("[are wonded]")).arg(((float)newStats.needHeal)*100.0f/((float)newStats.totalUnit), 0, 0).c_str());
 
 		// upgrade state
-		gfx->drawString(textStartPosX, textStartPosY+174, globalContainer->littleFont, GAGCore::nsprintf("%s %d/%d/%d/%d", strings->getString("[Walk]"), newStats.upgradeState[WALK][0], newStats.upgradeState[WALK][1], newStats.upgradeState[WALK][2], newStats.upgradeState[WALK][3]).c_str());
-		gfx->drawString(textStartPosX, textStartPosY+186, globalContainer->littleFont, GAGCore::nsprintf("%s %d/%d/%d", strings->getString("[Swim]"), newStats.upgradeState[SWIM][1], newStats.upgradeState[SWIM][2], newStats.upgradeState[SWIM][3]).c_str());
-		gfx->drawString(textStartPosX, textStartPosY+198, globalContainer->littleFont, GAGCore::nsprintf("%s %d/%d/%d/%d", strings->getString("[Build]"), newStats.upgradeState[BUILD][0], newStats.upgradeState[BUILD][1], newStats.upgradeState[BUILD][2], newStats.upgradeState[BUILD][3]).c_str());
-		gfx->drawString(textStartPosX, textStartPosY+210, globalContainer->littleFont, GAGCore::nsprintf("%s %d/%d/%d/%d", strings->getString("[Harvest]"), newStats.upgradeState[HARVEST][0], newStats.upgradeState[HARVEST][1], newStats.upgradeState[HARVEST][2], newStats.upgradeState[HARVEST][3]).c_str());
-		gfx->drawString(textStartPosX, textStartPosY+222, globalContainer->littleFont, GAGCore::nsprintf("%s %d/%d/%d/%d", strings->getString("[At. speed]"), newStats.upgradeState[ATTACK_SPEED][0], newStats.upgradeState[ATTACK_SPEED][1], newStats.upgradeState[ATTACK_SPEED][2], newStats.upgradeState[ATTACK_SPEED][3]).c_str());
-		gfx->drawString(textStartPosX, textStartPosY+234, globalContainer->littleFont, GAGCore::nsprintf("%s %d/%d/%d/%d", strings->getString("[At. strength]"), newStats.upgradeState[ATTACK_STRENGTH][0], newStats.upgradeState[ATTACK_STRENGTH][1], newStats.upgradeState[ATTACK_STRENGTH][2], newStats.upgradeState[ATTACK_STRENGTH][3]).c_str());
+		gfx->drawString(textStartPosX,textStartPosY+174, globalContainer->littleFont, FormatableString("%0 %1/%2/%3/%4").arg(strings->getString("[Walk]")).arg(newStats.upgradeState[WALK][0]).arg(newStats.upgradeState[WALK][1]).arg(newStats.upgradeState[WALK][2]).arg(newStats.upgradeState[WALK][3]).c_str());
+		gfx->drawString(textStartPosX, textStartPosY+186, globalContainer->littleFont, FormatableString("%0 %1/%2/%3").arg(strings->getString("[Swim]")).arg(newStats.upgradeState[SWIM][1]).arg(newStats.upgradeState[SWIM][2]).arg(newStats.upgradeState[SWIM][3]).c_str());
+		gfx->drawString(textStartPosX, textStartPosY+198, globalContainer->littleFont, FormatableString("%0 %1/%2/%3/%4").arg(strings->getString("[Build]")).arg(newStats.upgradeState[BUILD][0]).arg(newStats.upgradeState[BUILD][1]).arg(newStats.upgradeState[BUILD][2]).arg(newStats.upgradeState[BUILD][3]).c_str());
+		gfx->drawString(textStartPosX, textStartPosY+210, globalContainer->littleFont, FormatableString("%0 %1/%2/%3/%4").arg(strings->getString("[Harvest]")).arg(newStats.upgradeState[HARVEST][0]).arg(newStats.upgradeState[HARVEST][1]).arg(newStats.upgradeState[HARVEST][2]).arg(newStats.upgradeState[HARVEST][3]).c_str());
+		gfx->drawString(textStartPosX, textStartPosY+222, globalContainer->littleFont, FormatableString("%0 %1/%2/%3/%4").arg(strings->getString("[At. speed]")).arg(newStats.upgradeState[ATTACK_SPEED][0]).arg(newStats.upgradeState[ATTACK_SPEED][1]).arg(newStats.upgradeState[ATTACK_SPEED][2]).arg(newStats.upgradeState[ATTACK_SPEED][3]).c_str());
+		gfx->drawString(textStartPosX, textStartPosY+234, globalContainer->littleFont, FormatableString("%0 %1/%2/%3/%4").arg(strings->getString("[At. strength]")).arg(newStats.upgradeState[ATTACK_STRENGTH][0]).arg(newStats.upgradeState[ATTACK_STRENGTH][1]).arg(newStats.upgradeState[ATTACK_STRENGTH][2]).arg(newStats.upgradeState[ATTACK_STRENGTH][3]).c_str());
 		
 		// happyness
 		std::stringstream happyness;
@@ -437,19 +441,41 @@ int TeamStats::getStarvingUnits()
 bool TeamStats::load(GAGCore::InputStream *stream, Sint32 versionMinor)
 {
 	stream->readEnterSection("TeamStats");
-	endOfGameStatIndex = stream->readSint32("endOfGameStatIndex");
-	for (int i=0; i<TeamStats::END_OF_GAME_STATS_SIZE; i++)
+	Uint32 size=0;
+	if(versionMinor>=50)
+	{
+		size=stream->readUint32("size");
+	}
+	else
+	{
+		size=128;
+		stream->readSint32("endOfGameStatIndex");
+	}
+
+	bool stop=false;
+	
+	for (unsigned int i=0; i<size; i++)
 	{
 		stream->readEnterSection(i);
-		endOfGameStats[i].value[EndOfGameStat::TYPE_UNITS] = stream->readSint32("EndOfGameStat::TYPE_UNITS");
-		endOfGameStats[i].value[EndOfGameStat::TYPE_BUILDINGS] = stream->readSint32("EndOfGameStat::TYPE_BUILDINGS");
-		endOfGameStats[i].value[EndOfGameStat::TYPE_PRESTIGE] = stream->readSint32("EndOfGameStat::TYPE_PRESTIGE");
+		Sint32 units = stream->readSint32("EndOfGameStat::TYPE_UNITS");
+		Sint32 buildings = stream->readSint32("EndOfGameStat::TYPE_BUILDINGS");
+		Sint32 prestige = stream->readSint32("EndOfGameStat::TYPE_PRESTIGE");
+		Sint32 hp = 0;
+		Sint32 attack = 0;
+		Sint32 defense = 0;
 		if (versionMinor > 31)
 		{
-			endOfGameStats[i].value[EndOfGameStat::TYPE_HP] = stream->readSint32("EndOfGameStat::TYPE_HP");
-			endOfGameStats[i].value[EndOfGameStat::TYPE_ATTACK] = stream->readSint32("EndOfGameStat::TYPE_ATTACK");
-			endOfGameStats[i].value[EndOfGameStat::TYPE_DEFENSE] = stream->readSint32("EndOfGameStat::TYPE_DEFENSE");
+			hp = stream->readSint32("EndOfGameStat::TYPE_HP");
+			attack = stream->readSint32("EndOfGameStat::TYPE_ATTACK");
+			defense = stream->readSint32("EndOfGameStat::TYPE_DEFENSE");
 		}
+		if(versionMinor<50)
+		{
+			if(units==0 && buildings==0 && prestige==0 && hp==0 && attack==0 && defense==0)
+				stop=true;
+		}
+		if(!stop)
+			endOfGameStats.push_back(EndOfGameStat(units, buildings, prestige, hp, attack, defense));
 		stream->readLeaveSection();
 	}
 	stream->readLeaveSection();
@@ -459,8 +485,8 @@ bool TeamStats::load(GAGCore::InputStream *stream, Sint32 versionMinor)
 void TeamStats::save(GAGCore::OutputStream *stream)
 {
 	stream->writeEnterSection("TeamStats");
-	stream->writeSint32(endOfGameStatIndex, "endOfGameStatIndex");
-	for (int i=0; i<TeamStats::END_OF_GAME_STATS_SIZE; i++)
+	stream->writeUint32(endOfGameStats.size(), "size");
+	for (unsigned int i=0; i<endOfGameStats.size(); i++)
 	{
 		stream->writeEnterSection(i);
 		stream->writeSint32(endOfGameStats[i].value[EndOfGameStat::TYPE_UNITS], "EndOfGameStat::TYPE_UNITS");
