@@ -19,9 +19,14 @@
 
 #include "Unit.h"
 #include "Race.h"
+#include "UnitSkin.h"
+#include "UnitsSkins.h"
 #include "Team.h"
 #include "Map.h"
 #include "Game.h"
+
+#include "Building.h"
+
 #include "Utilities.h"
 #include "GlobalContainer.h"
 #include "LogFileManager.h"
@@ -39,7 +44,9 @@ Unit::Unit(int x, int y, Uint16 gid, Sint32 typeNum, Team *team, int level)
 	logFile = globalContainer->logFileManager->getFile("Unit.log");
 	
 	// unit specification
-	this->typeNum=typeNum;
+	this->typeNum = typeNum;
+	defaultSkinNameFromType();
+	skinPointerFromName();
 
 	assert(team);
 	race=&(team->race);
@@ -82,34 +89,34 @@ Unit::Unit(int x, int y, Uint16 gid, Sint32 typeNum, Team *team, int level)
 	else
 		movement=MOV_RANDOM_GROUND;
 
-	targetX=0;
-	targetY=0;
-	validTarget=false;
-	magicActionTimeout=0;
+	targetX = 0;
+	targetY = 0;
+	validTarget = false;
+	magicActionTimeout = 0;
 
 	// trigger parameters
 	hp=0;
 
-	// warriors fight to death TODO: this is overided !?!?
+	// warriors fight to death TODO: this is overridden !?!?
 	if (performance[ATTACK_SPEED])
-		trigHP=0;
+		trigHP = 0;
 	else
-		trigHP=20;
+		trigHP = 20;
 
 	// warriors wait more tiem before going to eat
-	hungry=HUNGRY_MAX;
+	hungry = HUNGRY_MAX;
+	hungryness = race->hungryness;
 	if (performance[ATTACK_SPEED])
-		trigHungry=(hungry*2)/10;
+		trigHungry = (hungry*2)/10;
 	else
-		trigHungry=hungry/4;
-	trigHungryCarying=hungry/10;
-	fruitMask=0;
-	fruitCount=0;
-
+		trigHungry = hungry/4;
+	trigHungryCarying = hungry/10;
+	fruitMask = 0;
+	fruitCount = 0;
 
 	// NOTE : rewrite hp from level
-	hp=this->performance[HP];
-	trigHP=(hp*3)/10;
+	hp = this->performance[HP];
+	trigHP = (hp*3)/10;
 
 	attachedBuilding=NULL;
 	targetBuilding=NULL;
@@ -133,6 +140,11 @@ void Unit::load(GAGCore::InputStream *stream, Team *owner, Sint32 versionMinor)
 	
 	// unit specification
 	typeNum = stream->readSint32("typeNum");
+	if (versionMinor >= 49)
+		skinName = stream->readText("skinName");
+	else
+		defaultSkinNameFromType();
+	skinPointerFromName();
 	race = &(owner->race);
 	assert(race);
 
@@ -176,6 +188,10 @@ void Unit::load(GAGCore::InputStream *stream, Team *owner, Sint32 versionMinor)
 
 	// hungry
 	hungry = stream->readSint32("hungry");
+	if (versionMinor >= 49)
+		hungryness = stream->readSint32("hungryness");
+	else
+		hungryness = race->hungryness;
 	trigHungry = stream->readSint32("trigHungry");
 	trigHungryCarying = (trigHungry*4)/10;
 	fruitMask = stream->readUint32("fruitMask");
@@ -237,6 +253,7 @@ void Unit::save(GAGCore::OutputStream *stream)
 	// unit specification
 	// we drop the unittype pointer, we save only the number
 	stream->writeSint32(typeNum, "typeNum");
+	stream->writeText(skinName, "skinName");
 
 	// identity
 	stream->writeUint16(gid, "gid");
@@ -270,6 +287,7 @@ void Unit::save(GAGCore::OutputStream *stream)
 
 	// hungry
 	stream->writeSint32(hungry, "hungry");
+	stream->writeSint32(hungryness, "hungryness");
 	stream->writeSint32(trigHungry, "trigHungry");
 	stream->writeUint32(fruitMask, "fruitMask");
 	stream->writeUint32(fruitCount, "fruitCount");
@@ -744,7 +762,7 @@ void Unit::handleMedical(void)
 	
 	if (verbose)
 		printf("guid=(%d) handleMedical...\n", gid);
-	hungry-=race->hungryness;
+	hungry -= hungryness;
 	if (hungry<=0)
 		hp--;
 	
@@ -788,7 +806,8 @@ void Unit::handleMedical(void)
 				owner->map->setGroundUnit(posX, posY, NOGUID);
 				
 			// generate death animation
-			owner->map->getSector(posX, posY)->deathAnimations.push_back(new UnitDeathAnimation(posX, posY, owner));
+			if (!globalContainer->runNoX)
+				owner->map->getSector(posX, posY)->deathAnimations.push_back(new UnitDeathAnimation(posX, posY, owner));
 		}
 		isDead = true;
 	}
@@ -822,9 +841,9 @@ void Unit::handleActivity(void)
 				Building *b=owner->findBestFoodable(this);
 
 				int dist;
+				int timeLeft = numberOfStepsLeftUntilHungry();
 				// Is there a building we can reach in time?
-				const int timeLeft=(hungry-trigHungry)/race->hungryness;
-				if (b!=NULL && owner->map->buildingAvailable(b, performance[SWIM], posX, posY, &dist) && dist<timeLeft)
+				if (b!=NULL && owner->map->buildingAvailable(b, performance[SWIM], posX, posY, &dist) && dist < timeLeft)
 				{
 					bool canSubscribe=(caryedRessource>=0) && b->neededRessource(caryedRessource);
 
@@ -1269,7 +1288,7 @@ void Unit::handleDisplacement(void)
 					if (ressourceToTake>=0)
 					{
 						int foreignBuildingDist;
-						int timeLeft=(hungry-trigHungry)/race->hungryness;
+						int timeLeft = numberOfStepsLeftUntilHungry();
 						if (owner->map->buildingAvailable(foreingExchangeBuilding, performance[SWIM], posX, posY, &foreignBuildingDist)
 							&& (foreignBuildingDist<(timeLeft>>1)))
 						{
@@ -1380,9 +1399,8 @@ void Unit::handleDisplacement(void)
 						attachedBuilding->wishedRessources(needs);
 						int teamNumber=owner->teamNumber;
 						bool canSwim=performance[SWIM];
-						int timeLeft=(hungry-trigHungry)/race->hungryness;
-						
-						if (timeLeft>0)
+						int timeLeft = numberOfStepsLeftUntilHungry();
+						if (timeLeft > 0)
 						{
 							int bestRessource=-1;
 							int minValue=owner->map->getW()+owner->map->getW();
@@ -1715,6 +1733,24 @@ void Unit::handleDisplacement(void)
 	}
 }
 
+bool Unit::locationIsInEnemyGuardTowerRange(int x, int y)const
+{
+	//TODO: totally fix this totally hacky implementation.
+	for(int i=0;i<32;i++)
+	{
+		Team *t = owner->game->teams[i];
+		if((t)&&(owner->enemies & t->me))
+		{
+			for(int j=0;j<1024;j++)
+			{
+				Building *b = t->myBuildings[j];
+				if((b)&&(b->shortTypeNum==IntBuildingType::DEFENSE_BUILDING)&&(owner->map->warpDistMax(b->posX,b->posY,posX,posY) <= b->type->shootingRange + 1))return true;
+			}
+		}
+	}
+	return false;
+}
+
 void Unit::handleMovement(void)
 {
 	// clearArea code, override behaviour locally
@@ -1796,17 +1832,23 @@ void Unit::handleMovement(void)
 				const int dyTab[8] = {-2, -4, -4, -2, +2, +4, +4, +2};
 				int tab[8];
 				for (int i = 0; i < 8; i++)
+				{
 					tab[i] = owner->map->getExplored(posX + dxTab[i], posY + dyTab[i], owner->teamNumber);
+					//also move around enemy towers:
+					if(locationIsInEnemyGuardTowerRange(posX + dxTab[i], posY + dyTab[i]))tab[i]=1;
+				}
 				//printf("tab ");
 				//for (int i = 0; i < 8; i++)
 				//	printf("%3d; ", tab[i]);
 				//printf("d=%d\n", direction);
 				for (int di = 0; di < 8; di++)
 				{
-					int d = (di + direction + 4) & 7;
-					if ((tab[d] > 0) && (tab[(d + 1) & 7] == 0) && (tab[(d + 2) & 7] == 0))
+					int d = (di + direction + 4) % 8;
+					//Move in a direction in which you circle counter-clockwise
+					//about explored area, while exploring.
+					if ((tab[d] > 0) && (tab[(d + 1) % 8] == 0) && (tab[(d + 2) % 8] == 0))
 					{
-						direction = (d + 1) & 7;
+						direction = (d + 1) % 8;
 						dxdyfromDirection();
 						movement = MOV_GOING_DXDY;
 						found = true;
@@ -2220,8 +2262,13 @@ void Unit::handleAction(void)
 		{
 			assert(performance[FLY]);
 			owner->map->setAirUnit(posX, posY, NOGUID);
-			dx=-1+syncRand()%3;
-			dy=-1+syncRand()%3;
+			for(int q = 0; q < 5; ++q) //hack - look for a direction safe from guard towers
+			{
+				dx=-1+syncRand()%3;
+				dy=-1+syncRand()%3;
+				if(locationIsInEnemyGuardTowerRange(posX + dx, posY + dy))continue;
+				else break;
+			}
 			directionFromDxDy();
 			setNewValidDirectionAir();
 			posX=(posX+dx)&(owner->map->getMaskW());
@@ -2661,34 +2708,98 @@ Uint16 Unit::GIDfrom(Sint32 id, Sint32 team)
 	return id+team*1024;
 }
 
+//! Return the real armor, taking into account the reduction due to fruits
 int Unit::getRealArmor(void) const
 {
 	int armorReductionPerHappyness = race->getUnitType(typeNum, level[ARMOR])->armorReductionPerHappyness;
 	return performance[ARMOR] - fruitCount * armorReductionPerHappyness;
 }
 
+//! Return the real attack strengh, taking into account the experience level
 int Unit::getRealAttackStrength(void) const
 {
 	return performance[ATTACK_STRENGTH] + experienceLevel;
 }
 
+//! Return the amount of experience to level-up
 int Unit::getNextLevelThreshold(void) const
 {
 	return (experienceLevel + 1) * (experienceLevel + 1) * race->getUnitType(typeNum, level[ATTACK_STRENGTH])->experiencePerLevel;
 }
 
+//! Increment experience. If level-up occures, handle it. Multiple level-up may occur at once.
 void Unit::incrementExperience(int increment)
 {
-	int nextLevelThreshold = getNextLevelThreshold();
 	experience += increment;
-	if (experience > nextLevelThreshold)
+	int nextLevelThreshold = getNextLevelThreshold();
+	while (experience > nextLevelThreshold)
 	{
-		experienceLevel++;
 		experience -= nextLevelThreshold;
+		experienceLevel++;
+		nextLevelThreshold = getNextLevelThreshold();
 		levelUpAnimation = LEVEL_UP_ANIMATION_FRAME_COUNT;
 	}
 }
 
+//! Compute the skin pointer from a skin name
+void Unit::skinPointerFromName(void)
+{
+	if (!globalContainer->runNoX)
+	{
+		skin = globalContainer->unitsSkins->getSkin(skinName);
+		if (skin == NULL)
+		{
+			// if skin is invalid, retry with default
+			std::cerr << "Unit::skinPointerFromName : invalid skin name " << skinName << std::endl;
+			defaultSkinNameFromType();
+			skin = globalContainer->unitsSkins->getSkin(skinName);
+			if (!skin)
+				abort();
+		}
+	}
+	else
+		skin = NULL;
+}
+
+
+//! Compute the skin name from the unit type
+void Unit::defaultSkinNameFromType(void)
+{
+	switch (typeNum)
+	{
+		case WORKER: skinName = "worker"; break;
+		case EXPLORER: skinName = "explorer"; break;
+		case WARRIOR: skinName = "warrior"; break;
+		default: assert(false); break;
+	}
+}
+
+//! Return how many steps we can do until we are hungry
+int Unit::numberOfStepsLeftUntilHungry(void)
+{
+	int timeLeft;
+	if (hungryness)
+		timeLeft = (hungry-trigHungry) / hungryness;
+	else
+		timeLeft = INT_MAX;
+	stepsLeftUntilHungry = timeLeft;
+	return timeLeft;
+}
+
+//! Iterate on all resource types to see if it is gettable
+void Unit::computeMinDistToResources(void)
+{
+	bool allResourcesAreTooFar = true;
+	for (size_t ri = 0; ri < MAX_RESSOURCES; ri++)
+		if (!owner->map->ressourceAvailable(owner->teamNumber, ri, performance[SWIM], posX, posY, &minDistToResource[ri]))
+			minDistToResource[ri] = -1;
+		else if (minDistToResource[ri] < stepsLeftUntilHungry)
+			allResourcesAreTooFar = false;
+	// the dist to an already carried resource is zero
+	if (caryedRessource >= 0)
+		minDistToResource[caryedRessource] = 0;
+}
+
 void Unit::integrity()
 {
 	assert(gid<32768);
