@@ -41,8 +41,9 @@
 #include "GlobalContainer.h"
 #include "NetConsts.h"
 #include "LogFileManager.h"
-#include <StringTable.h>
 
+#include <FormatableString.h>
+#include <StringTable.h>
 
 // If you don't have SDL_net 1.2.5 some features won't be available.
 #ifndef INADDR_BROADCAST
@@ -706,7 +707,9 @@ void YOG::treatPacket(IPaddress ip, Uint8 *data, int size)
 					Message message;
 					message.gameGuiPainted=false;
 					message.messageType=YCMT_EVENT_MESSAGE;
-					snprintf(message.text, 256, Toolkit::getStringTable()->getString("[The player %s has joined YOG]"), client.userName);
+					FormatableString tmp(Toolkit::getStringTable()->getString("[The player %0 has joined YOG]"));
+					tmp.arg(client.userName);
+					strncpy(message.text, tmp.c_str(), 512);
 					receivedMessages.push_back(message);
 				}
 				
@@ -757,7 +760,9 @@ void YOG::treatPacket(IPaddress ip, Uint8 *data, int size)
 						Message message;
 						message.gameGuiPainted=false;
 						message.messageType=YCMT_EVENT_MESSAGE;
-						snprintf(message.text, 256, Toolkit::getStringTable()->getString("[The player %s has left YOG]"), client->userName);
+						FormatableString tmp(Toolkit::getStringTable()->getString("[The player %0 has left YOG]"));
+						tmp.arg(client->userName);
+						strncpy(message.text, tmp.c_str(), 512);
 						receivedMessages.push_back(message);
 						clients.erase(client);
 					}
@@ -781,7 +786,7 @@ void YOG::treatPacket(IPaddress ip, Uint8 *data, int size)
 								Message message;
 								message.gameGuiPainted=false;
 								message.messageType=YCMT_EVENT_MESSAGE;
-								snprintf(message.text, 256, "%s", Toolkit::getStringTable()->getString("[You are now marked as away]"));
+								strncpy(message.text, Toolkit::getStringTable()->getString("[You are now marked as away]"), 512);
 								receivedMessages.push_back(message);
 							}
 							client->away=true;
@@ -794,7 +799,7 @@ void YOG::treatPacket(IPaddress ip, Uint8 *data, int size)
 								Message message;
 								message.gameGuiPainted=false;
 								message.messageType=YCMT_EVENT_MESSAGE;
-								snprintf(message.text, 256, "%s", Toolkit::getStringTable()->getString("[You are no more marked as away]"));
+								strncpy(message.text, Toolkit::getStringTable()->getString("[You are no more marked as away]"), 512);
 								receivedMessages.push_back(message);
 							}
 							client->away=false;
